ADJECTIVES = ['quadraspazzed', 'bouncing', 'rotating', 'polystyrene', 'plastic', 'decongesting', 'defibrulating',
              'purple', 'screaming', 'bouncy', 'gyrating', 'smiling', 'red', 'polka-dotted', 'four-wheeled', 'inedible',
              'happy', 'crunchy', 'crispy', 'steel-plated', 'copper', '#NOUN-eating', 'pointy', 'clockwork',
              'pebble-dashed', 'false', 'fake', 'shoddy', 'copper-bottomed', 'metal', 'wooden', 'fluffy', 'stupid',
              'chocolate-coated', 'sugar-coated', 'fluorescent', 'shiny', 'lime-flavoured', 'rumbling', 'minty',
              'depressed', 'sinister', 'huge', 'stripey', 'cuddly', 'lovely', 'splendid', 'slimy', 'rusty', 'dangerous',
              'concrete', 'dark', 'flying', 'Burmese', 'Latvian', 'cheeky', 'clockwork', 'laughing', 'sniffling',
              'gigantic', 'tiny', 'paper-mache', 'vibrating', 'humming', 'singing', 'sugary', 'defaced', 'violent',
              'cheerful', 'sharp', 'bubbly', 'robotic', 'dead', 'broken', 'mad', 'Scottish', 'smelly', 'frightening',
              'possessed', 'gold-plated', 'gas-powered', 'sugar-free', 'blood-stained', 'Norwegian',
              'brightly-coloured', 'talkative', 'schizophrenic', 'grandiloquent', 'tungsten', 'polite', 'shockproof',
              'sticky', 'defunct', 'strange', 'mysterious', 'bizarre', 'spooky', 'beautiful', 'gorgeous', 'repulsive',
              'dying', 'wounded', 'retractable', 'hovering', 'magical', 'poisonous', 'bamboo', 'wicker', 'sleeping',
              'stain-digesting', 'stone-age', 'rubber', 'home-made', 'free-range', 'waterproof', 'puce', 'microscopic',
              'Fisher Price', 'multi-coloured', 'flaming', 'stout', 'curvy', 'bent', 'half-empty', 'flamboyantly',
              'prehistoric', 'faulty', 'shattered', 'very big', 'freezing', 'dirty', 'Taiwanese', 'beastly',
              'piezo-electronic', 'clever', 'brilliant', 'hideous', 'cunning', 'horrible', 'kindly', 'fat', 'thin',
              'French', 'robust', 'Cornish', 'curmudgeonly', 'magnetic', 'fusion-powered', 'tidy', 'revolting',
              'slippery', 'toasted', 'cracked', 'perfect', 'new', 'granite', 'strawberry-flavoured', 'chortling',
              'miniaturised', 'hairy', 'plastic', 'Chinese', 'tinned', 'frozen', 'cheap and nasty', 'loud',
              'fossilised', 'Welsh', 'flattened', 'leather-bound', 'holy', 'giggling', 'crude', 'belligerent',
              'highly-polished', 'winged', 'bi-pronged', 'soggy', 'fluff-covered', 'lithium', 'horrid', 'curt',
              'lighter-than-air', 'hollow', 'heavy', 'rabid', 'fizzy', 'wet', 'muddy', 'battle-scarred',
              'jewel-encrusted', 'black and white', 'tartan', 'bogus', 'boarded-up', 'derelict', 'soggy', 'blow-up',
              'three-legged', 'tepid', 'badly-disguised', 'laconic', 'speedy', 'swirly', 'flawed', 'mauve', 'hopeless',
              'reinforced', 'futuristic', 'post-modern', 'feeble', 'tremendous', 'wandering', 'sweet-smelling', 'tall',
              'short', 'red-hot', 'skeletal', 'diabetic', 'lethal', 'fatal', 'second-best', 'grey', 'bulging',
              'short-circuited', 'flanged', 'stupid', 'gold-trimmed', 'twisted', 'steaming', 'pretty', 'peppermint',
              'butterscotch', 'fluffy', 'satanic', 'diseased', 'mouldy', 'spandex', 'cubist', 'heartless',
              'tomato-filled', 'naked', 'toasted', 'waterlogged', 'dehydrated', 'rubber', 'spiky', 'puerile',
              'childish', 'cute', 'fake rubber', 'spooky', 'maniacal', 'greasy', 'manic-depressive', 'suicidal',
              'chrome', 'mad', 'BSE-infected', 'green-flavoured', 'paisley', 'tartan-edged', 'nasty', 'paranoid',
              'pyrophobic', 'claustrophobic', 'fiendish', 'glowing', 'musical', 'dancing', 'transparent', 'green',
              'flawless', 'prickly', 'venusian', 'demonic', 'bored', 'Polish', 'runaway', 'worthless', 'priceless',
              'furious', 'vinegar-soaked', 'tea-stained', 'frabjous', 'slippery', 'mauve', 'carpeted', 'house-trained',
              'pointy-toothed', 'gaudy', 'grinning', 'frowning', 'crying', 'sneezing', 'sugar-free', 'caffeine-free',
              'fruit-flavoured', 'happy-go-lucky', 'rudimentary', 'deathly', 'quite poisonous', 'stupifying',
              'frivolous', 'annoying', 'dreadful', 'cruel', 'suicidal', 'vindictive', 'bouncy', 'Vulcan', 'silent',
              'Russian', 'multi-lingual', 'multi-purpose', 'lighter-than-air', 'dictatorial', 'pox-ridden',
              'smallpox-infected', 'fatal', 'cut-price', 'off-white', 'leaky', 'stinking', 'tie-dyed', 'tasteless',
              'deceitful', 'petrified', 'dubious', 'subterranean', 'homeless', 'Swiss', 'fifteenth-century',
              'Rubinesque', 'genuine', 'three-eyed', 'highly dangerous', 'semi-naked', 'badly-wired', 'semi-aquatic',
              'tropical', 'gloopy', 'Welsh', 'yellow', 'damp', 'vodka-drinking', 'white', 'black', 'cordless', 'rude',
              'skeletal', '300-year-old', 'lumpy', 'renegade', 'revolutionary', 'brightly-haired', 'fractured',
              'lovable', 'stainless steel', 'poison-coated', 'little', 'family-sized', 'greasy', 'precious',
              'Victorian', 'bright yellow', 'dayglo purple', 'silly', 'sleeping', 'sleepy', 'cretinous', 'stunned',
              'moronic', 'hightly intelligent', 'super-intelligent', 'sentient', 'high-voltage', 'sensitive',
              'cruel and nasty', 'shiny', 'scratched', 'Swiss', 'tedious', 'low-flying', 'ravenous', 'flared',
              'brightly-glowing', 'hyperactive', 'spicy', 'fabulous', 'Kafkaesque', 'babyish', 'rotting',
              'sesquipedalianist', 'lactose-intolerant', 'hairy', 'bevelled', 'slim', 'government-issue', 'damp',
              'soggy', 'dripping-wet', 'waterlogged', 'pine-fresh', 'bendy', 'big', 'rather old-fashioned', 'gay',
              'merry', 'pert', 'blue', 'indigo', 'part-time', 'mediocre', 'medium-sized', 'extra-large', 'urine-soaked',
              'petrol-soaked', 'misanthropic', 'misty', 'miserly', 'ready-salted', 'pirated', 'intelligent',
              'intellectual', 'promulent', 'electronic', 'disgusting', 'disgraceful', 'hopping-mad', 'merciful',
              'Y2K-compliant', 'impressive', 'impossible', 'impossibly-shaped', 'bloody', 'blinking', 'pesky', 'giddy',
              'lean', 'lemon-flavoured', 'sorry', 'eighteenth-century', 'tense', 'tender', 'tenacious', 'eight-legged',
              'shrunken', 'glass-bottomed', 'Serbian', 'serrated', 'servile', 'serious', 'serendipitous', 'serene',
              'serviceable', 'vampiric', 'undead', 'very, very big', 'jolly good', 'jolly', 'spiffing', 'top-notch',
              'haploid', 'darkness-cloaked', 'goddamn', 'Green-clearance', 'Ultraviolet-clearance', 'Orwellian',
              'flat-topped', 'flat-bottomed', 'bug-eyed', 'buggered', 'large', 'pungent', 'frilly', 'hot', 'unwilling',
              'grave', 'unlit', 'fuzzy-felt', 'young', 'sad', 'scrawny', 'scruffy', 'bad', 'year-old', 'bright',
              'brittle', 'briny', 'British', 'bricked-up', 'bridal', 'curvaceous', 'satirical', 'satisfied',
              'saturated', 'satiated', 'saturnine', 'weak', 'weary', 'weak-kneed', 'strangely-shaped', 'straw',
              'strained', 'straight', 'stranded', 'first-edition', 'glistening', 'glib', 'glittery', 'stained',
              'stained-glass', 'hooded', 'exotic', 'excellent', 'exciting', 'extra', 'perspex', 'aromatic', 'aroused',
              'arousing', 'rotten', 'salacious', 'selfish', 'selfless', 'flabby', 'flapping', 'mucky', 'filthy',
              'filter-tipped', 'frigid', 'fried', 'free', 'freakish', 'freaky', 'inaccurate', 'giggly',
              'very #ADJECTIVE', 'extremely #ADJECTIVE', 'anomalous', 'plump', 'freshly-plucked', 'burning', 'buried',
              'simple', 'meek', 'lame', 'rotund', 'shocking', 'pleased', 'favourable', 'checkmated', 'male', 'female',
              'talking', 'computer-generated', 'Babylonian', 'single', 'sobbing', 'soapy', 'art-nouveau', 'art-deco',
              'experimental', 'unnecessary', 'brazen', 'silvery-grey', '#NOUN-digesting', 'rather old-fashioned',
              'dodgy', 'dubious', 'bloated', 'sesquipedalianist', 'badly-designed', 'mind-numbingly dull', 'chitinous',
              'bulbous', 'nebulous', 'bleesome', 'honey-roasted', 'mean', 'glass', 'pedantic', 'perfect', 'flat',
              'diced', 'mythical', 'fictional', 'gloopy', 'paisley', "hot 'n' spicy", 'buzzing', 'mouldy', 'wafer-thin',
              'Cantonese', 'Finnish', 'khaki', 'rubbery', 'cursed', 'blessed', 'blessed +4', 'sparkly', 'semi-human',
              'tall, dark', 'scented', 'royal', 'ridiculous', 'very silly', 'stunning', 'radioactive', 'wandering',
              'fearsome', 'curried', 'prefabricated', 'vegetarian', 'red, blue and yellow', 'tearful', 'heartless',
              'perverse', 'bulbous', 'nebulous', 'skinny', 'hairy', 'reanimated', 'half-dead', 'sleepy', 'chubby',
              'gibbering', 'Christian', 'horrible hairy', 'sparkly', 'giant', 'pine-scented', 'nice new', 'pathetic',
              'omnivorous', 'neo-Fascist', 'neo-Nazi', 'headless', 'two-headed', 'hexagonal', 'slippery', 'pale',
              'skeletal', 'semi-transparent', 'semi-detached', 'pus-filled', 'banana-flavoured', 'slimy', 'ghostly',
              'nice and cosy', 'tiresome', 'spiteful', 'horse', 'rubberised', 'bloody', 'stupid bloody buggering',
              'bisexual', 'north-facing', 'kinky', 'lucky', 'high-altitude', 'green-flavour', 'red-flavour', 'tattered',
              'Cardassian', 'Tibetan', 'curved', 'firm', 'squishy', 'collapsed', 'shagged-out', 'knobbly',
              'broken-hearted', 'loud', 'silent', 'photo-sensitive', 'photogenic', 'dynamic', 'thrusting',
              'stark naked', 'teenage', 'stinking', 'burgundy', 'forged', 'leather-upholstered', 'nervous', 'sexy',
              'funny', 'funny-smelling', 'Gallifreyan', 'godawful', 'crouching', 'sluggish', 'diesel-powered', 'puce',
              'cybernetic', 'smug', 'contented', 'blind', 'deaf', 'transparent', 'gaseous', 'see-through', 'fuzzy',
              'straggly', 'white', 'golden', 'silver', 'crap', 'pathetic and snivelling', 'spring-heeled', 'tactless',
              'tactful', 'tepid', 'naughty', 'barking-mad', 'mighty', 'hexagonal', 'pointillist', 'babyish',
              'sleepwalking', 'crumbling', 'cracked', 'precious', 'sweet', 'sour', 'shrivelled', 'throbbing',
              'blood-stained', 'foetal', 'cosmic', 'drug-addled', 'swift', 'limp', 'flatulent', 'statuesque',
              'world-famous', 'silly knees-bent running-about', 'dessicated', 'cockney', 'pan-galactic', 'truttaceous',
              'old', 'ancient', 'electric', 'oven-ready', 'erotic', 'empty', 'important', 'unimportant', 'invisible',
              'undercover', 'invulnerable', 'impressionable', 'incoherent', 'unsteady', 'unstoppable', 'opaque',
              'alien', 'Irish', 'inimitable', 'aching', 'orgasmic', 'organic', 'antique', 'elderly', 'old', 'infirm',
              'alcoholic', 'black', 'squeaky', 'tiny little', 'Lego', 'erect', 'podgy', 'adorable', 'underwater',
              'nameless', 'unnamed', 'unpopular', 'unfriendly', 'bawdy', 'angry', 'albino', 'enormous', 'oafish',
              'octagonal', 'origami', 'orange-flavoured', 'cheesy', 'antimatter', 'imitation', 'oven-ready',
              'transvestite', 'iron', 'baby', 'significant', 'insignificant', 'curious', 'limpid', 'reasonably-priced',
              'ominous', 'pear-shaped', 'pornographic', 'flickering', 'world-famous', 'Italian', 'moping', 'irksome',
              'gutless', 'spineless', 'Spanish', 'wax', 'split-crotch', 'out-of-this-world', 'jovial', 'over-excited',
              'small, plastic', 'newborn', 'Celtic', 'Transylvanian', 'eidetic', 'shiny-on-the-inside', 'buxom',
              'stereotypical', 'spangly', 'badly-scratched', 'craven', 'ghastly', 'arrogant', 'genetically-modified',
              'fin-de-siecle', 'chunky', 'slim-line', 'genetically-unstable', 'organic', 'three-inch', 'impish',
              'silver-plated', 'bargain-priced', 'hapless', 'excited', 'dead', 'rhythmical', 'stealthy',
              'gut-wrenching', 'talking', 'faux-marble', 'gin-soaked', 'ugly', 'rat-arsed', 'amusing', 'confusing',
              'baffling']

FAULTS = [
    "#NOUN.c:#RANDOM[500,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,256,257,258,259,260,261,262,263,264,265,266,267,268,269,270,271,272,273,274,275,276,277,278,279,280,281,282,283,284,285,286,287,288,289,290,291,292,293,294,295,296,297,298,299,300,301,302,303,304,305,306,307,308,309,310,311,312,313,314,315,316,317,318,319,320,321,322,323,324,325,326,327,328,329,330,331,332,333,334,335,336,337,338,339,340,341,342,343,344,345,346,347,348,349,350,351,352,353,354,355,356,357,358,359,360,361,362,363,364,365,366,367,368,369,370,371,372,373,374,375,376,377,378,379,380,381,382,383,384,385,386,387,388,389,390,391,392,393,394,395,396,397,398,399,400,401,402,403,404,405,406,407,408,409,410,411,412,413,414,415,416,417,418,419,420,421,422,423,424,425,426,427,428,429,430,431,432,433,434,435,436,437,438,439,440,441,442,443,444,445,446,447,448,449,450,451,452,453,454,455,456,457,458,459,460,461,462,463,464,465,466,467,468,469,470,471,472,473,474,475,476,477,478,479,480,481,482,483,484,485,486,487,488,489,490,491,492,493,494,495,496,497,498,499,500]: #ADJECTIVE #RANDOM[2,fault,error] #RANDOM[2,in '#NOUN()',before '#NOUN'] - #RANDOM[5,'#NOUN' undeclared,'#NOUN' is not #AN #NOUN,out of #NOUNs,#NOUN is not set to an instance of a #NOUN,missing #NOUN].",
    "#ADJECTIVEError: cannot #VERB '#NOUN' and '#NOUN' objects.",
    "Traceback (most recent call last):  File '/#NOUN/#NOUN/#ADJECTIVE_#NOUN/#NOUN.py', line #RANDOM[20,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20], in #ADJECTIVE_#NOUN.  #ADJECTIVEError: #NOUN #RANDOM[4,should,will not,cannot,did not] #RANDOM[2,#VERB #NOUN,#VERB #AN #ADJECTIVE #NOUN]."]

NAMES = ['Julian Assange', 'Jake Gyllenhaal', 'Mao Tse Tung', "Radiohead's lead singer", 'Suede', 'Neil Armstrong',
         'Jimminy Crickett', 'Trent Reznor', 'Marilyn Manson', 'Brandon Lee', 'Eric Draven', 'The Cure', 'Robert Smith',
         'The X-Men', 'Jackie Chan', 'Lou Reed', 'Pearl Jam', 'REM', 'Pulp', 'Margaret Thatcher', 'John Major',
         'Bill Clinton', 'Abraham Lincoln', 'Saddam Hussein', 'Aladdin', 'Hansel and Gretel', 'Yogi Bear', 'Scooby Doo',
         'Hong Kong Phooey', 'Mr Spoon', 'Mickey Mouse', 'Donald Duck', 'Daffy Duck', 'Dick Dastardly',
         'Captain Planet', 'Leonardo Da Vinci', 'Bugs Bunny', 'Godzilla', 'Ronald McDonald', 'Fred Flintstone',
         'Wilma Flintstone', 'Barney the Dinosaur', 'The Governator', 'Jeff K', 'LowTax', 'Nik', 'Eperdu',
         'Kim Jong Il', 'Kim Il Sung', 'George W Bush', 'Tony Blair', 'Al Gore', 'Jesse Ventura', 'Anne Hathaway',
         'Michael Douglas', 'Beyonce', 'Gary Barlow', 'Sharon Osborne', 'Lewis Hamilton', 'Sebastian Vettel',
         'Mark Wahlberg', 'Tom Cruise', 'Nicole Kidman', 'Jensen Button', 'Oprah Winfrey', 'Lady Gaga',
         'Steven Spielberg', 'Madonna', 'Taylor Swift', 'Bon Jovi', 'Roger Federer', 'Justin Bieber', 'Ellen DeGeneres',
         'Hugh Jackman', 'Jennifer Lopez', 'Rihanna', 'Tiger Woods', 'LeBron James', 'Simon Cowell', 'Katy Perry',
         'David Beckham', 'Robert Downey Jr', 'Leonardo DeCaprio', 'Tyler Perry', 'Channing Tatum', 'Kobe Bryant',
         'Dwayne Johnson', 'Ryan Seacrest', 'Seth MacFarlane', 'Donald Trump', 'Jay-Z', 'Will Smith', 'Ben Affleck',
         'Neo', 'David Letterman', 'Adam Sandler', 'Angelina Jolie', 'Jamers Patterson', 'Howard Stern', 'Usain Bolt',
         'Jennifer Lawrence', 'Rafael Nadal', 'Peter Jackson', 'Serena Williams', 'Jerry Bruckheimer', 'Kanye West',
         'Jerry Seinfeld', 'Michael Bay', 'Maria Sharapova', 'Dr Dre', 'Jennifer Aniston', 'Kim Kardashian',
         'Charlie Sheen', 'Calvin Harris', 'Kristen Stewart', 'Gwynneth Paltrow', 'Meryl Streep', 'David Guetta',
         'Stephen King', 'Christopher Nolan', 'Gordon Ramsay', 'Tina Fey', 'J.K. Rowling', 'Alec Baldwin', 'Emma Stone',
         'Charlize Theron', 'Neil Patrick Harris', 'Mila Kunis', 'Sandra Bullock', 'Danica Patrick', 'Zooey Deschanel',
         'Joss Whedon', 'Miranda Kerr', 'Al Pacino', 'Johnny Depp', 'Russell Crowe', 'Denzel Washington',
         'Robert De Niro', 'Jack Nicholson', 'George Clooney', 'Morgan Freeman', 'Colin Farrell', 'Ralph Fiennes',
         'Harrison Ford', 'Tommy Lee Jones', 'Samuel L. Jackson', 'Christian Bale', 'Nicholas Cage', 'Pierce Brosnan',
         'Bradley Cooper', 'Mel Gibson', 'Brad Pitt', 'Jason Statham', 'Forest Whitaker', 'Orlando Bloom',
         'Martin Lawrence', 'Hugh Laurie', 'Riddick', 'Gary Oldman', 'Antonio Banderas', 'Laurence Fishburne',
         'Viggo Mortensen', 'Bruce Willis', 'Clint Eastwood', 'Jeremy Renner', 'Matt Damon', 'Alan Rickman',
         'Barack Obama', 'Harry Potter', 'Voldermort', 'Heath Ledger', 'Superman', 'The Joker', 'Batman']

NOUNS = ['life-glug', 'banana', 'toaster', 'stoat', 'goat', 'herring', 'table-lamp', 'water-buffalo', 'terrapin',
         'saucepan', 'kitchen', 'cloud', 'clown', 'kettle', 'gerbil', 'bottle', 'nose', 'drainpipe', 'hat', 'hammer',
         'lightbulb', 'breadbin', 'hatstand', 'spade', 'nostril', 'toddler', 'stone', 'starling', 'carrier bag',
         'refridgerator', 'pebble', 'crow', 'gnome', 'spoon', 'trifle', 'mouth', 'moth', 'Spaniard', 'battleship',
         'mother', 'jumper', 'washing machine', 'pterodactyl', 'grape', 'teapot', 'teabag', 'cheeseboard', 'purse',
         'bishop', 'kidney', 'tube train', 'turnip', 'sprout', 'dolphin', 'scarf', 'clam', 'squid', 'brick', 'biro',
         'car', 'llama', 'leg', 'hair', 'horse', 'bucket', 'coffee-mug', 'spatula', 'pepperpot', 'lollipop', 'boy',
         'girl', 'mandarin', 'mongoose', 'stickleback', 'Lego brick', 'thing', 'dustbin', 'sponge', 'fork', 'laser-gun',
         'mechanical digger', 'shirt', 'sock', 'shoe', 'wafer', 'tree', 'nail', 'sugarlump', 'sword', 'corkscrew',
         'window', 'carrot', 'hearing aid', 'vampire', 'duffel-coat', 'monkey', '#NOUN-container', 'fishcake', 'teacup',
         'spaceship', 'crystal', 'ring', 'handbag', 'gun', 'chequebook', 'snake', 'viper', 'truncheon', 'bubble',
         'biscuit', 'hob-nob', 'sponge finger', 'toenail', 'rake', 'carpark', 'screwdriver', 'pitchfork', 'seagull',
         'sausage', 'parrot', 'scalpel', 'pillow', 'toilet', 'duck', 'kilt', 'rabbit', 'Mini Metro', 'demon', 'pen',
         'drawing pin', 'dog collar', 'licence', 'salad', 'shrub', 'father', 'vicar', 'waiter', 'meringue', 'pensioner',
         'tongue', 'bomb', 'youngster', 'MUSHer', 'microwave', 'pocket', 'shoelace', 'movie star', 'ballpoint pen',
         'feather', 'piano', 'traffic cone', 'snooker cue', 'football', 'landmine', 'motorbike', 'pedalo',
         'cheque guarantee card', 'whisk', 'leotard', 'leopard', 'postage stamp', 'wizard', 'computer',
         'computer keyboard', 'floppy disk', 'modem', 'boat', 'fritter', 'tortoise', 'breezeblock', 'glass eye',
         'spirit level', 'compost heap', 'triffid', 'calendar', 'intern', 'wand', 'cuckoo clock', 'cuckoo', 'clock',
         'ghost', 'wraith', 'heart', 'chair', 'grenade', 'cup', 'dishwasher', 'plunger', 'flask', 'monster', 'chicken',
         'turkey', 'snail', 'petticoat', 'spear', 'lemon-squeezer', 'pencil sharpener', 'weather balloon',
         'helium balloon', 'plum', 'flute', 'harp', 'parsnip', 'gravy-boat', 'submarine', 'barrel',
         'toxic waste barrel', 'magnet', 'thermometer', 'triangle', 'pipette', 'manhole cover', 'rat', 'liver',
         'sea urchin', 'thumb', 'chainsaw', 'rope', 'cigarette', 'newspaper', 'beard', 'razor blade',
         'time-travel device', 'cow', 'kipper', 'gyroscope', 'pound', 'dollar', 'weasel', 'grapefruit', 'tripe ration',
         'potion', 'space alien', 'psychiatrist', 'dentist', 'power drill', 'bath', 'bathplug', 'phaser',
         "Blake's 7 teleport bracelet", 'janitor', 'stick', 'coffin', 'jar', 'chimney', 'taxi', 'flamethrower',
         'library ticket', 'web', 'spider', 'tractor', 'drink', 'novel', 'magazine', 'monk', 'nun', 'aspirin', 'table',
         'toilet roll', 'mousetrap', 'star', 'piston engine', 'gorilla', 'dinosaur', 'party popper', 'weevil',
         'video cassette', 'noseplug', 'yoghurt', 'limb', 'handkerchief', 'burglar alarm', 'lightning conductor',
         'bible', 'signpost', 'sink', 'shopkeeper', 'dragon', 'cockatrice', 'corpse', 'scroll', 'kitten', 'whale',
         'X-File', 'hole', 'vest', 'cufflink', 'yoghurt pot', 'honey-pot', 'bee', 'wasp', 'lover', 'treefrog',
         'tea-strainer', 'golf club', 'frying pan', 'bandanna', 'weak lemon drink', 'Klingon', 'Dalek', 'golfball',
         'television', 'mousetrap', 'crisp', 'coke can', 'typewriter', 'tube map', 'clotheshorse', 'mop', 'dishcloth',
         'bumper sticker', 'hedgehog', 'comb', 'head', 'trumpet', 'javelin', 'cannonball', 'wastepaper basket',
         'goldfish bowl', 'two-bob bit', 'machine', 'nut', 'peanut', 'brazil nut', 'cold cure', 'tablet', 'gravestone',
         'great-great-grandfather', 'wire', 'telephone', 'necklace', 'flower', 'double-yellow line', 'compact disc',
         'Pulp album', 'worm', 'paintpot', 'doorbell', 'Frankenstein mask', 'rock', 'jellybean', 'dolly mixture',
         'gumdrop', 'paper bag', 'mirror', 'bikini', 'cement mixer', 'tiepin', 'tea-chest', 'thigh', 'shirt button',
         'toad', 'catapult', 'daffodil', 'cowpat', 'pixie', 'goblin', 'leprechaun', 'plug', 'roadsign',
         'driving instructor', 'coal bunker', 'cheese-grater', 'Viking longboat', 'stalagmite', 'stalagtite',
         'fire engine', 'photocopier', 'fax machine', 'porpoise', 'mutant', 'tub', 'tyre', 'blender', 'machine-gun',
         'machete', 'tourist', 'knight', 'gold coin', 'raven', 'Glaswegian', 'snorkel', 'biplane', 'ruler',
         'budgerigar', 'fire axe', 'suit', 'mobile phone', 'paperback book', 'religious symbol', 'dictaphone',
         'thirteen-amp fuse', 'hippo', 'choc-ice', 'Pot Noodle', 'hosepipe', 'salamander', 'raindrop', 'portrait',
         'photograph', 'traffic warden', 'pigeon', 'hornet', 'spitfire', 'hoover', 'sock', 'golem', 'tricycle',
         'traffic light', 'fairy godmother', 'hammock', 'dream', 'hallucination', 'sniper', 'rifle', 'terrorist',
         'cake', 'ice-cream cone', 'jelly tot', 'chocolate bar', 'lettuce', 'boiled egg', 'lamb', 'shark', 'chainsaw',
         'desk drawer', 'cabinet', 'prize', 'dumb-waiter', 'flapjack', 'lemon', 'melon', 'nuclear weapon', 'satellite',
         'video', 'splinter', 'kaleidoscope', 'spleen', 'mushroom', 'cabbage', 'pear drop', 'fountain', 'cherub',
         'Toilet Duck', 'burglar', 'beagle', 'giraffe', 'hypodermic needle', 'cotton swab', 'bandage', 'spike',
         'nailfile', 'paving slab', 'sofa', 'statue', 'wax model', 'maniac', 'talisman', 'geranium', '#NOUN-detector',
         'n()-repellent', 'ferret', 'clarinet', 'comet', 'ham and cheese omelette', 'puppet', 'clothespeg', 'bosom',
         'lager', 'trombone', 'power tool', 'hedge-trimmer', 'wheelbarrow', 'barge', 'pike', 'pentagram',
         'pencil crayon', 'goat skull', 'bagel', 'widget', 'grommet', 'flange', 'takeaway meal', 'penny farthing',
         'molotov cocktail', 'cocktail umbrella', 'tennis ball', 'shuttlecock', 'radio', 'pylon', 'python', 'vacuum',
         'tachyon', 'manuscript', 'car exhaust', 'thunderbolt', 'hailstone', 'backpack', 'J-cloth', 'threshing machine',
         'bubble bath', 'milkbottle', 'rag', 'capybara', 'pendulum', 'banjo', 'klaxon', 'bacon-slicer', 'crop circle',
         'minstrel', 'teddybear', 'diode', 'steak-and-kidney pie', 'mantelpiece', 'rottweiler', 'hamburger', 'magician',
         'letter-opener', 'love poem', 'bulldozer', 'JCB', 'spirograph', 'DNA-strand', 'space shuttle', 'sock', 'beast',
         'martian', 'Christmas tree', 'parsnip', 'clog', 'bap', 'donkey', 'barbecue', 'cymbal', 'choc-ice', 'mountain',
         'mole', 'stick', 'glove', 'candle', 'blackboard', 'rubber', 'petrol pump', 'farmer', 'UHT milk carton',
         'muppet', 'cripple', 'chip', 'saveloy', 'marrow', 'cucumber', 'tripod', 'bunsen burner', 'beaker',
         'tax inspector', 'disc jockey', 'pipecleaner', 'pizza', 'keep-left sign', 'pianist', 'magpie', 'cuspidor',
         'beer pump', 'pyramid', 'shed', 'zombie', 'lump', 'fiend', 'friend', 'fossil', 'trilobite', 'fern', 'flag',
         'key', 'UFO', 'mask', 'parcel', 'salt cellar', 'triffid', 'midget', 'hand-drill', 'trowel', 'greenhouse',
         'bridge', 'plank', 'vodka', 'fish-slice', 'guillotine', 'bell', 'doorbell', 'landlord', 'Doctor Who fan',
         'supercomputer', 'river', 'stream', 'heart', 'gourd', 'hoe', 'solar panel', 'nuclear power station', 'lemming',
         'wendy house', 'little girl', 'little boy', 'log', 'lumberjack', 'tunnel', 'novelist', 'forest', 'bicycle',
         'token', 'fruit machine', 'Trivial Pursuit board', 'Monopoly counter', 'Scrabble tile', 'greyhound', 'zebra',
         'bum', 'barley sugar', 'sherbet fountain', 'power cable', 'microwave', 'tumble dryer', 'kitchen sink', 'skirt',
         'fruit pastille', 'robe', 'camera', 'camel', 'morris dancer', 'Morris Minor', 'nail', 'barometer', 'poacher',
         'shotgun', 'priest', 'rubber band', 'birdcage', 'tramp', 'religious zealot', 'minnow', 'pilchard', 'firework',
         'balloon', 'headrest', 'pillowcase', 'razor', 'dinosaur', 'bus ticket', 'etching', 'woodshed', 'plectrum',
         'intern', 'cornflake', 'cream cake', 'gargoyle', 'Morrissey album', 'key-ring', 'bath towel', 'table-lamp',
         'beer tankard', 'space-hopper', 'Turin shroud', 'painting', 'sculpture', 'Beta Reticulan', 'Wookie', 'Vulcan',
         'Romulan', 'hydrogen bomb', 'kidney bean', 'pecan pie', 'passport photo', 'wine gum', 'telephone kiosk',
         'cinema usherette', 'bacon roll', 'cro-magnon', 'sword', 'lilo', 'Post-It note', 'barcode-reader',
         'cartridge pen', 'HB pencil', 'chair', 'footstool', 'toenail', 'vodka and tonic', 'angler', 'fishing rod',
         'Star Trek costume', 'helmet', 'rapier', 'broadsword', 'rifle', 'gatling gun', 'bomb', 'fool', 'jester',
         'clown', 'cyanide capsule', 'boulder', 'caterpillar', 'millipede', 'centipede', 'scorpion', 'tablecloth',
         'tricorder', 'salmon mousse', 'clock', 'crib', 'cricket stump', 'grasshopper', 'Christmas pudding', 'tuba',
         'skirt', 'shirt', 'toilet seat', 'thorn', 'gadget', 'lion', 'stick', 'stick insect', 'cod fillet', 'bandage',
         'figurine', 'flagstone', 'French flag', 'circuit board', 'torture device', 'thumbscrew', 'sewing machine',
         'nutter', 'rattle', 'lab coat', 'Easter Island statue', 'warp drive', 'jug', 'lemonade bottle',
         'sweet wrapper', 'typhoon', 'basking shark', 'leaflet', 'camera', 'wok', 'bulldozer', 'radio', 'teabag',
         'tea-strainer', 'roadworks sign', 'vice-president', 'goalkeeper', 'creature', 'trenchcoat', 'war wound',
         'needle', 'lager can', 'quill', 'porcupine', 'bull', 'bird dropping', 'goldfish pond', 'bicycle', 'librarian',
         'mandrill', 'beetle', 'charcoal briquette', 'leper', 'plague victim', 'engine part', 'neanderthal',
         'Betamax video recorder', 'fruit stall', 'spring roll', 'seahorse', 'hamster', 'koi carp', 'weed', 'stool',
         'telescope', 'Polo mint', 'smiley-face badge', "'Ban Nuclear Power' placard", 'French horn', "wizard's hat",
         'robot', 'philosopher', 'mime artist', 'grappling hook', 'Mandelbrot set', 'Pratchett novel', 'swivel chair',
         'sofa', 'coffee table', 'table lamp', 'Sony walkman', 'Lowry print', 'newspaper', 'cannon', 'gas oven', 'poet',
         'Buddhist', 'Dragon 32', 'tax return', 'tax invoice', 'partridge', 'tapir', 'telepath', 'psychopath',
         'Penny Black', 'ten-pound note', 'gyroscope', 'slide-rule', 'cardboard tube', 'party hat', 'knuckle', 'finger',
         'single-celled lifeform', 'soup spoon', 'milk carton', 'fedora', 'washing-up rack', 'figgin', 'florin', 'bowl',
         'pint mug', 'first-class stamp', 'scuba-diving kit', 'Rod Hull impersonator', 'cornflake',
         'Mighty Morphin Power Ranger', 'paper bag', 'car key', 'sixteen-ton weight', 'spleen', 'road', 'Ming vase',
         'Satanist', 'champagne bottle', 'genie', 'washing line', 'lupin', 'flamingo', 'three-toed sloth',
         'flying saucer', 'man-size tissue', 'Mars bar', 'flowerpot', 'necklace', 'poodle', 'dobermann pinscher',
         'duvet', 'badger', 'lampshade', 'toadstool', 'sausage roll', 'rattlesnake', 'lizard', 'newt', 'jackal',
         'family photo album', 'gazelle', 'metal pole', 'garden fence', "'Keep Off The Grass' sign", 'temporal warp',
         'gryphon', 'penguin', 'hobbit', 'magpie', 'device', 'black pudding', 'crash helmet', 'daffodil', 'thing',
         'wossname', 'chihuahua', 'chocolate sponge-cake', 'pig', 'yoghurt', 'nihilist', 'straightjacket', 'false limb',
         'baseball cap', 'motor boat', 'grandmother', 'teenager', 'shrimp', 'prawn', 'fire hydrant', 'spaniel', 'panda',
         'warthog', 'saucepan', 'beansprout', 'swashbuckler', 'burger', 'rat', 'lesbian', 'cow', 'banshee',
         'wellington boot', 'duckling', 'sausage', 'chicken kiev', 'millionaire', 'quilt', 'vacuum tube',
         'cathode ray tube', 'transistor', 'toy phone', 'seashell', 'chip pan', 'pear', 'flower', 'lamb', 'rubber duck',
         'cello', 'strawberry ice-cream', 'waistcoat', 'Belgian', 'spaghetti hoop', 'piccolo', 'Texan', 'poppy seed',
         'sunflower', 'soya bean', 'wooden stake', 'loft', 'hamper', 'guillotine', 'Chinese meal', 'horse', 'chopstick',
         "frog's leg", 'long-sleeved shirt', 'bone', 'table-tennis table', 'troll', 'fletton', 'farmyard animal',
         'fern', 'toadstool', 'walnut', 'pomegranate', 'feather duster', 'feather boa', 'boa constrictor',
         "'Give Way' sign", 'palm tree', 'traffic cone', 'spade', 'cornflake', 'grapefruit', 'kiwi fruit', 'plough',
         'scythe', 'police radio', 'gremlin', 'shrub', 'Mornington Crescent grandmaster', 'student union card',
         'passport', 'bright green marker pen', 'stepladder', 'beggar', 'door-handle', 'stapler', 'staple',
         'blue anorak', 'Thermos flask', 'snowball', 'toilet seat', 'harp', 'fire engine', 'harlequin',
         'shopping trolley', 'puma', 'genie', 'stick', 'kipper tie', 'dove', 'pencil sharpener', 'beach towel', 'towel',
         'firelighter', 'gemstone', 'bedspring', 'denim jacket', 'wedding ring', 'mineral deposit', 'spatula', 'limpet',
         'landmine', 'lung', 'Guiness truck', 'troll', 'milk churn', 'koi carp', 'metal detector', 'chip fork',
         'slipper', 'banana skin', 'proton', 'soup spoon', 'guttersnipe', 'pickpocket', 'spark plug', 'Tipp-Ex bottle',
         'Pritt-Stick', 'paracetamol', 'hallucinogenic drug', 'cassock', 'ferret', 'drumstick', 'Um Bongo carton',
         'polystyrene cup', 'coffee stirrer', 'vinegar bottle', 'trenchcoat', 'maggot', 'caterpillar', 'beer barrel',
         'bicycle pump', 'blowlamp', 'vagrant', 'drill bit', 'radiator', 'blanket', 'fire blanket', 'colostomy bag',
         'beetle', 'deep-fat frier', 'collarbone', 'ribcage', 'con artist', 'banshee', 'poltergeist', 'dry white wine',
         'bottle opener', 'spring roll', 'diamond', 'knight', 'tinned pear', 'straightjacket', 'stapler',
         'blank cheque', 'chocolate egg', 'carry-cot', 'button', 'toupee', 'neanderthal', 'cave painting', 'groupie',
         'banjo', 'C compiler', 'duck', 'garden gnome', 'boot', 'big black coat', 'band-aid', 'spotlight',
         'car sticker', 'Clanger', 'street map', 'tarantula', 'Dilbert cartoon', 'wig', 'boyfriend', 'girlfriend',
         'lampshade', 'bra', 'carpet tile', 'washing-up bowl', 'newt', 'lamp-post', 'bobbin', 'Volvo', 'lizard',
         'sweet wrapper', 'drain cover', 'crystal ball', 'playing card', 'glove puppet', 'xenomorph', 'facehugger',
         'farming implement', 'fjord', 'warm-air hand-drier', 'paper towel', 'napkin', 'punch bowl', 'frying pan',
         'ferris wheel', 'porridge-bowl', 'camera obscura', 'lathe', 'gyroscope', 'jigsaw piece', 'parson',
         'long-sleeved shirt', 'woolly mammoth', 'wine bottle', 'ex-girlfriend', 'ex-boyfriend', 'pest',
         'sucker monkey', 'code-monkey', 'bar chart', 'token', 'cobblestone', 'dog kennel', 'bust', 'income-tax form',
         'liar', 'rapscallion', 'thing-a-ma-jig', 'milk carton', 'Dickens novel', 'Underground train', 'jacket', 'gum',
         'boil', 'Morrissey fan', 'ice floe', 'albino', 'Millennium Dome', 'manticore', 'garlic bulb', 'drag-queen',
         'live-in lover', 'coat', 'cop', 'copper', 'copper wire', 'dancer', 'Great Dane', 'farm', 'arch-enemy',
         "ne'er-do-well", 'cocoon', 'grue', 'map', 'troubleshooter', 'brain', 'face', 'factory-worker', 'facepack',
         'Kafka novel', 'bear', 'beaver', 'sad-act', 'salt crystal', 'sanguine', 'bug', 'bugger', 'lackey', 'amethyst',
         'mullet', 'hot dinner', 'grave', 'supermarket', 'hand grenade', 'hand-grenade pin', 'bugle', 'bugbear', 'bung',
         'cougar', 'count', 'cough', 'kagoul', 'house', 'houseboat', 'tutu', 'tuna salad', 'au pair', 'undergarment',
         'pie', 'apple pie', 'apple', 'apricot', 'ape', 'moray eel', 'behemoth', 'teacher', 'maths teacher', 'hood',
         'lift', 'lifeform', 'virgin', 'miller', 'poisoner', 'person', 'perm', 'pervert', 'lucky charm', 'frog', 'rod',
         'arse', 'girl guide', 'freak', 'polymath', 'poltroon', 'pole', 'pole-vaulter', 'polyp', 'polecat', 'saviour',
         'savage', 'sneeze', 'water droplet', 'scientist', 'scientologist', 'peon', '#ADJECTIVE mask', 'horror',
         'woggle', 'paper hat', 'pit-trap', 'bow', 'bowler hat', 'shop', 'pear tree', 'patio door', 'pen lid',
         'laser printer', 'cgi-script', 'cheesecake', "'wanted' poster", 'weathervane', 'hidden camera', 'phone booth',
         'undergraduate', 'babe', 'Babylonian', 'prospector', 'saxophone', 'nasty little sticky thing', 'breadboard',
         'pumpkin', "Hallowe'en mask", 'dove', "'Five of Cups' Tarot card", 'merry-go-round', 'vegetarian',
         'police dog', 'vinegar-sprinkler', 'pumpkin', "hallowe'en mask", 'Frankenstein mask', 'siren', 'gannet',
         'thalassomaniac', 'Web browser', 'sandcastle', 'firework', 'Sticklebrick', 'Fuzzy Felt piece',
         'printer ribbon', 'snowplough', 'nail-file', 'lizard monster', 'fire elemental', 'Christmas decoration',
         'fake beard', 'clown', 'tax disc', 'magic wand', 'frock', 'starting pistol', 'fern', 'telnet client',
         'sten gun', 'train ticket', 'bus driver', 'squid', 'gargoyle', 'lobster', 'nymph', 'nymphomaniac', 'Sontaran',
         'foot spa', 'drinks machine', 'coffee bean', 'mentholated cough sweet', 'vampire bat', 'time warp',
         'printed circuit board', 'palm tree', 'ballerina', 'spinning top', 'programmer', 'cherry stone', 'cowboy',
         'boulder', 'lampshade', 'lifeboat', 'snowflake', 'driving licence', 'hairnet', 'spelling mistake', 'jumper',
         'paperweight', 'lip', 'colostomy bag', 'radiator', 'firelighter', 'lawnmower', 'Harrier jump-jet',
         'salt-and-vinegar crisp', 'birthday card', 'bread and butter pudding', 'monkey', 'laboratory rat', 'ganglion',
         'boy band', "spider's web", 'big toe', 'croissant', 'slipper', 'pyramid', 'hairgrip', 'fireball', 'bloke',
         'cyborg', 'vegetable', 'matchstick', 'Star Wars figure', 'vol-au-vent', 'lottery ticket', 'moomin', 'flannel',
         'fighter plane', 'rabbit dropping', 'kakapo', 'cockatiel', 'strange object', 'grape', 'grapefruit',
         'American-Indian', 'marshmallow', 'Ferrero Rocher', 'cellist', 'kneecap', 'collarbone', 'party hat',
         'chip fork', 'piranha', 'conger eel', 'potion', 'raisin', 'rubber ring', 'water-wing', 'moose', 'gnu',
         'newsreader', 'weathergirl', 'soap-on-a-rope', 'Crunchy Frog', 'shoe-horn', 'supermodel', 'mermaid', 'faerie',
         "horse's head", 'zebra crossing', 'gearstick', 'poetry book', 'bouncy castle', 'knight', 'calendar',
         'Chocolate Orange', 'canned ham', 'rice cake', 'memo', 'playing card', 'TIE Fighter', 'X-Wing', 'gibbon',
         'tiger', 'jump lead', 'Christian', 'cork', 'merkin', 'sugarplum', 'parson', 'bicycle chain', 'breast',
         'key-ring', 'Tyranid', 'mynah bird', 'monolith', 'hedgehog', 'faerie', 'kebab', 'sparkler', 'windmill',
         'cabinet minister', 'Magic: The Gathering card', 'feather boa', 'public toilet', 'mangrove', 'penguin',
         'suitcase', 'bra-strap', 'sperm whale', 'goldfish bowl', 'bar-fire', 'MIDI system', 'Canadian Mountie',
         'pilchard', 'Blockbusters contestant', 'hexagon', 'pirate', 'tulip', 'partridge', 'party popper', 'heron',
         'buffet car', 'laptop', 'bead', 'chandelier', 'piston engine', 'Wankel rotary engine', 'Cray supercomputer',
         'Kray twin', 'slipper', 'bodyguard', 'paper towel', 'drain', 'coffee percolator', 'sandwich toaster', 'badger',
         'bed-sit', 'luxury yacht', 'Nobel prize', 'Morrissey mask', 'conquistador', 'Jelly-Baby head', 'cube',
         'cylinder', 'piano wire', 'picture frame', 'skyscraper', 'cashew nut', 'tentacle', 'cattle-prod', 'clam',
         'houseplant', 'bastard', 'semi-precious stone', 'poppadum', 'pond', 'ladder', 'flapjack', 'flip-flop', 'crumb',
         'Disney character', 'flying carpet', 'nut', 'book token', 'hazelnut', 'mountain goat', "Hell's Angel",
         'lie detector', 'blowpipe', 'pacamac', 'buoy', 'road sign', 'beanbag', 'koi carp', 'groupie', 'chopstick',
         'train', 'cemetery gate', 'Zygon', 'phantom', 'lathe', 'padlock', 'gold ingot', 'dartboard', 'tentacle',
         'venus fly-trap', 'man-eating plant', 'tablet', 'blob', 'boyfriend', 'overcoat', 'nostril', 'security guard',
         'shepherd', 'Labour party candidate', 'fright wig', 'road-map', 'sticky label', 'cone', 'mallard', 'peacock',
         'Pac-Man arcade machine', 'blow-up doll', 'fish-head', 'garlic-crusher', 'brick wall', 'navel', 'button',
         'pizza', 'flashlight', "will-o'-the-wisp", 'urinal', 'tapeworm', 'dashboard', 'kiwi', 'kid',
         'reproductive organ', 'okapi', 'bluetit', 'monorail', 'meteorite', 'Goth', 'wart', 'hand', 'mockingbird',
         'Barbie doll', 'vagrant', 'toenail clipping', 'Smartie', "jester's cap", 'hyena', 'traffic light', 'sponge',
         'fire exit', 'seagull', 'rook', 'sitar', 'prostitute', 'childhood sweetheart', 'buzzer', 'hand-buzzer',
         'space monkey', 'household pet', 'pensioner', 'weevil', 'broadsword', 'Post-It note', 'net', 'net curtain',
         'birthday present', 'cucumber', "Fry's Chocolate Cream", 'Chocolate Orange', 'pinball machine', 'thigh',
         'forehead', 'sausage', 'neighbour', 'bathrobe', 'dressing gown', 'pipe', 'gibbon', 'hidden microphone',
         'corn-on-the-cob', 'jackrabbit', 'fingernail', 'student', 'lecturer', 'concertina', 'swamp',
         'tabloid newspaper', 'cartographer', 'cart', 'horse', 'mule', 'notebook', 'dirty magazine', 'blancmange',
         'mangetout', 'town crier', 'futon', 'jump-lead', 'magic bean', 'belt', 'lodestone', 'small boy', 'dog licence',
         'moth', 'crate', 'packing crate', 'duvet cover', 'duvet', "dunce's cap", 'skeleton', 'warlock', 'graveyard',
         'rolling pin', 'whoopie-cushion', 'donkey', 'egg', 'aubergine', 'elephant', 'imp', 'iguana', 'eel',
         'electric eel', 'ant', 'anteater', 'antelope', 'archer', 'ocelot', 'oven-glove', 'orang-utan', 'nickel',
         'orange', 'Opal Fruit', 'umbrella', 'anthill', 'odour-eater', 'electrode', 'Acorn Electron', 'Atari ST',
         'envelope', 'toe', 'owl', 'obelisk', 'ironing board', 'aardvark', 'ocelot', 'octagon', 'orange-juice carton',
         'clay pigeon', 'organist', 'organ', 'antique', 'elephant', 'eskimo', 'eggplant', 'bottle-top', 'udder',
         'eagle', 'sheepdog', 'autocue', 'Beefeater', 'skunk', 'arrow', 'babysitter', 'Spice Girl', 'horse',
         'little green pill', 'anti-depressant', 'melon', 'chimpanzee', 'index finger', 'contraceptive device',
         'bumble-bee', 'Goth', 'two-year-old', 'acupuncture needle', 'rhesus monkey', 'nettle', 'pot-plant', 'biker',
         'alien', 'eyeball', 'eye', 'elbow', 'puff-adder', 'bungalow', 'Tellytubby', 'fireball', 'enchanter', 'oaf',
         'clipboard', "otter's nose", 'otter', 'swivel chair', 'wing', 'oven', 'oven-ready chicken', 'bunion',
         'icecube', 'angel', 'marble', 'knob', 'fairy light', 'searchlight', 'android', 'Smiths album', 'amplifier',
         'Blake poem', 'bread roll', 'eyebrow', 'wood-chip', 'orchid', 'lotus petal', 'sticking plaster', 'angel',
         'frock', 'roadsign', 'birthday cake', 'asteroid', 'globe', 'bicycle clip', 'executive toy', 'panther',
         'ventriloquist', 'ticket inspector', 'wart', 'pimple', 'pushchair', 'engagement ring', 'stoat',
         'spelling mistake', 'fairy cake', 'fingernail', 'safety-pin', 'angel', 'gargoyle', 'poker chip', 'bullet',
         'gadget', 'omelette', 'haemorrhoid', 'Kinder egg', 'guest', 'snow-globe', 'stallion', 'concubine',
         'train-track', 'biosphere', 'badger', 'squirrel', 'GCSE exam', 'dilettante', 'sex maniac',
         'right-angled triangle', 'slug', 'non sequitur', 'moon rock', 'computer expert', 'organ', 'stop-sign',
         'wheel-clamp', 'nail', 'New Jersey slag-heap', 'goatee beard', 'Chunky Kit-Kat', 'stoat', 'Roman soldier',
         'thing', 'almond', 'lime', 'gin-and-tonic', 'rollercoaster', 'shopping basket', 'systems analyst', 'sieve',
         'goatherd', 'Pokemon', 'beak', 'bungee rope', 'souvenir', 'teardrop', 'PE teacher', 'teacup', 'pig', 'comic',
         'roadsign', 'plate-glass window', 'hippy-wig', 'cup', 'cracker', 'gannet', 'Microsoft product', 'tree',
         'cabinet minister', 'bluebell', 'yucca plant', 'aubergine', 'Sticklebrick', 'Robin Reliant', 'suspender',
         'bilingual', 'keyring', 'shuttlecock', 'Furby', 'jet engine', 'fax machine', 'light sabre',
         'particle accelerator', 'Scooby-snack', 'Ewok', 'puff-adder', 'gene']

SENTENCES = ['You #ADJECTIVE #NOUN!', "Your#ADJECTIVE_MAYBE #NOUN #RANDOM[2,is,isn't] #ADJECTIVE!",
             'Beware the #ADJECTIVE #NOUN!', 'Are you #AN #NOUN or #AN #NOUN?',
             'Would you like #AN #ADJECTIVE #NOUN?  #RANDOM[5,,,,,ANSWER ME!]',
             "I#RANDOM[2, am,'m] #AN #ADJECTIVE #NOUN#RANDOM[5,,, you know, apparently, according to the prophecy].",
             'Is it true that you #VERB#ADJECTIVE_MAYBE #NOUNs? #RANDOM[5,,,,,  ANSWER ME!]',
             "My #NOUN #RANDOM[3,,,'s #NOUN] #RANDOM[3,used to be,is really,looks like] #RANDOM[2,#AN #NOUN,#AN #ADJECTIVE #NOUN].",
             "Have you #RANDOM[3,seen,got,still got] my #ADJECTIVE #NOUN #RANDOM[3,,,'s #NOUN]?#RANDOM[5,,,,,  ANSWER ME!]",
             'Would you rather #VERB #RANDOM[3,#AN #ADJECTIVE #NOUN,#AN #NOUN,#NAME] or #VERB #RANDOM[4,#AN #ADJECTIVE #NOUN,#AN #NOUN,#NAME,me]?',
             "If you #VERB #RANDOM[2,me,my #NOUN], I'll #VERB #RANDOM[2,you,your #NOUN]...",
             "#RANDOM[3,We all know,I have reason to believe,I've proof] that you #RANDOM[3,,,can't] #VERB #NOUNs!",
             '#RANDOM[3,Mind,Watch out for,Keep away from] those#ADJECTIVE_MAYBE #NOUNs!  #RANDOM[3,,,They might #VERB you!]',
             "My #RANDOM[3,mother,father,parents] always told me I should#RANDOM[3, never,n't,,] #VERB #NOUNs.",
             "Are you trying to #VERB #RANDOM[4,#NAME,my #NOUN,#NAME's #NOUN,that#ADJECTIVE_MAYBE #NOUN]?",
             'Never #VERB #RANDOM[2,#AN #ADJECTIVE #NOUN,#AN #NOUN]!',
             "How dare you #VERB my#ADJECTIVE_MAYBE #NOUN#RANDOM[3,,,'s #NOUN]!",
             '#CAPITALISE #RANDOM[2,#NOUN,#ADJECTIVE #NOUN]s!  #CAPITALISE #RANDOM[6,thousands,hundreds,dozens,lots,billions,three] of them!#CAPITALISE#RANDOM[2,, all of them #ADJECTIVE!]',
             "#CAPITALISE #NOUNs and #NOUNs - #RANDOM[5,they both,neither of them,it's lucky they don't,I wish they'd,they often get together and] #VERB me.",
             '#CAPITALISE #VERB my#ADJECTIVE_MAYBE #NOUN!', "Why isn't my #NOUN #ADJECTIVE?",
             "Why #RANDOM[5,can't,don't,shouldn't,should,do] #NOUNs #VERB #NOUNs?",
             "If you didn't #VERB #NOUNs, #RANDOM[2,#NAME,the #NOUNs] wouldn't #VERB you.",
             "I'd rather #VERB #RANDOM[3,#AN #ADJECTIVE #NOUN,#AN #NOUN,#NAME] than #VERB #RANDOM[3,#AN #NOUN,#AN #ADJECTIVE #NOUN,#NAME].",
             # "#sq<0, #NAME>#sq<1,#NAME> #RANDOM<3>,<I hear that>,<It's said that>,<Apparently>> #gq<0> and  <#gq<0>,<#gq<1>>,<I>,<#gq<1>>>  #RANDOM<5>,<like to>,<frequently>,<sometimes>,<have been known to>,<never>>",
             "I'd #RANDOM[2,hate,love] to #VERB #NAME#RANDOM[2,,'s #NOUN]...",
             "#DEFINE_REPEAT[1,#ADJECTIVE #NOUN]#DEFINE_REPEAT[2,#NOUN]Ten #REPEAT[1]s, hanging on the #REPEAT[2] - ten #REPEAT[1]s, hanging on the #REPEAT[2] - and if one #REPEAT[1] should accidentally #VERB #RANDOM[2,#NAME,#AN #NOUN], there'd be nine #REPEAT[1]s, hanging on the #REPEAT[2].",
             # 'Email me at  #RANDOM[2,1,#sto#ADJECTIVE,->->>#sto<<#NOUN>,->@ #RANDOM<3>,<1>,<cyber->,<2>,<net->>#sto<<#NOUN>,> #RANDOM<3>,<1>,<-online>,<2>,<-net>>. #RANDOM<4>,<1>,<co.uk>,<2>,<net>,<3>,<com>,<org>>!',
             '#DEFINE_REPEAT[1,#NAME]#DEFINE_REPEAT[2,#NAME]Who do you think is #RANDOM[3,more #ADJECTIVE,more likely to #VERB #AN #NOUN,better to #VERB] -  #REPEAT[1], #REPEAT[2], me, #REPEAT[2] or #REPEAT[1]?',
             # "#CAPITALISE #VERB #AN #NOUN, #VERB #AN #NOUN - #RANDOM[5,it's all the same to me,just don't #RANDOM[2,come running to me when they,expect them to] #VERB you],just don't #VERB #AN #NOUN].",
             "I'm #ADJECTIVE - #RANDOM[3,perhaps I ought to,I think I'll,I'd better not] #VERB #RANDOM[2,#AN #NOUN,#NAME].",
             "I'm #AN #NOUN and I'm okay - I #VERB #NOUNs all night and I #VERB #NOUNs all day.",
             "If I had #AN #NOUN, I'd #VERB it in the #NOUN, I'd #VERB it in the #NOUN...",
             "I was #ADJECTIVE in the haze of #AN #ADJECTIVE #NOUN, but heaven knows I'm #ADJECTIVE now...",
             'Is this #AN #NOUN which I see before me, the #NOUN toward my #NOUN?  Come, let me #VERB thee.',
             '#DEFINE_REPEAT[1,#CAPITALISE #VERB #NOUNs]#REPEAT[1], #NAME.  #REPEAT[1] like #AN #ADJECTIVE #NOUN.',
             "If I can get the #NOUN to #VERB #RANDOM[3,#NAME,#NOUNs,#AN #NOUN], the #NOUN will #VERB #RANDOM[3,#NAME,#NOUNs,#AN #NOUN] and I'll be able to #VERB #RANDOM[3,#NAME,#NOUNs,#AN #NOUN]!",
             # 'Which of the following #RANDOM[3,has the #RANDOM[3,most,least,largest] #NOUNs,might #VERB #AN #NOUN,might #NAME #VERB]? A. #CAPITALISE #AN #NOUN. B. #CAPITALISE #AN #NOUN. C. #CAPITALISE #AN #NOUN. ',
             # "#RANDOM[2,I'm #RANDOM[2,terribly sorry, but,I'm afraid] I #RANDOM [2,have to,must] #VERB #RANDOM[3,your,my,that] #NOUN.",
             'I may have the #NOUN of #AN #ADJECTIVE and #ADJECTIVE #NOUN, but I have the #NOUN and #NOUN of #AN #NOUN.',
             '#NAME is like #AN #NOUN - #RANDOM[2,all #ADJECTIVE and #ADJECTIVE,#ADJECTIVE and full of #NOUNs].',
             'My #NOUN is full of#ADJECTIVE_MAYBE #NOUNs! Please #VERB my #NOUN.',
             '#CAPITALISE #NOUNs of the world - #VERB #NOUNs and #VERB #NOUNs!',
             '#CAPITALISE #VERB my #NOUN and tell me that you #VERB #RANDOM[3,me,#NAME,#NOUNs].',
             "My #ADJECTIVE #NOUN said #VERB the #NOUN, and don't #VERB #NOUNs on the way.",
             "Don't you just #RANDOM[2,love,hate] it when you #VERB #NOUNs and your #NOUN gets #ADJECTIVE?",
             "I'm a level #RANDOM[5,1,20,100,12,5] #NOUN, in #NOUN-world! I've got a magic #NOUN and everything!",
             'ALL YOUR #CAPALL #NOUN ARE BELONG TO US!',
             'We are the #ADJECTIVE #NOUNs. We are here to protect you from the #ADJECTIVE #NOUN of #NAME.',
             '#CAPALL DO NOT LEAVE IT IS NOT #ADJECTIVE!', 'I #VERB#ADJECTIVE_MAYBE #NOUNs!',
             "I've #RANDOM[2,always wanted to be,never been] #RANDOM[2,#ADJECTIVE,#AN #NOUN].",
             'Your mother was #AN #NOUN and your father smelled of #NOUNs.', 'How will I ever #VERB #AN #NOUN now?',
             "#RANDOM[4,If only,Oh,How I wish,I wish,I remember when] #RANDOM[2,I,my #NOUN] #RANDOM[2,was,wasn't] #ADJECTIVE...",
             'The #NOUNs - they #VERB me!', "I wish you wouldn't #VERB those #NOUNs.",
             'Never try to #VERB #NOUNs#RANDOM[5,,, with, in, on] #AN #NOUN.',
             "Don't #VERB me!  Not with that#ADJECTIVE_MAYBE #NOUN!  #RANDOM[3,Please!,Mercy!,Use the#ADJECTIVE_MAYBE #NOUN!]",
             "Look at #RANDOM[3,that,#NAME's,my]#ADJECTIVE_MAYBE #NOUN! #RANDOM[3,, Isn't it #ADJECTIVE?, Wouldn't it be nice to #VERB it?]",
             "#CAPITALISE #NOUNs - #VERB them or #VERB them, you can't #VERB them.",
             'Do you mind if I #VERB #RANDOM[2,you,your #NOUN]?  #RANDOM[5,,,,,  ANSWER ME!]',
             "I can't #VERB#ADJECTIVE_MAYBE #NOUNs without my#ADJECTIVE_MAYBE #NOUN.",
             "If you want to #VERB#ADJECTIVE_MAYBE #NOUNs, you'll need #RANDOM[2,to #VERB,#AN #NOUN].",
             "Don't #VERB#ADJECTIVE_MAYBE #NOUNs - #VERB#ADJECTIVE_MAYBE #NOUNs!",
             '#CAPITALISE #AN #NOUN a day keeps the #NOUN away.',
             "#DEFINE_REPEAT[1,#NAME]#DEFINE_REPEAT[2,#NOUN]And #REPEAT[1] said, 'Let there be #AN #REPEAT[2]', and there was #AN #REPEAT[2]. And #REPEAT[1] saw that the #REPEAT[2] was #ADJECTIVE, and #REPEAT[1] separated the #REPEAT[2] from the #NOUN.",
             'On the fifth day of Christmas, my #ADJECTIVE love sent to me - five #ADJECTIVE #NOUNs! Four #ADJECTIVE #NOUNs, three #ADJECTIVE #NOUNs, two #ADJECTIVE #NOUNs and #AN #NOUN in #AN #NOUN.',
             '#DEFINE_REPEAT[1,#NOUN]Jingle #REPEAT[1]s, Jingle #REPEAT[1]s, Jingle all the way - oh what fun it is to #VERB #NOUNs in a one-#NOUN #ADJECTIVE #NOUN.',
             'I heard that you like #NOUNs #RANDOM[3,spread on the bed,in the bath,in the dark] with #AN #ADJECTIVE #NOUN.',
             '#NAME #RANDOM[2,said,told me] you #RANDOM[3,had #AN #ADJECTIVE #NOUN,were #ADJECTIVE,might #VERB me]...',
             "Ooh, #RANDOM[2,,I'm so #ADJECTIVE,] I could #VERB #AN #NOUN!",
             "I wish #NAME would#RANDOM[2,,n't] #VERB #RANDOM[2,me,my #NOUN].",
             "Have you #RANDOM[3,seen,heard about,got] #NAME's#ADJECTIVE_MAYBE #NOUN?",
             "#RANDOM[3,About this time of night, I like to,I think it's time to,I fear it may be too late to] #VERB #RANDOM[2,#AN #NOUN,#NAME].",
             "I'd #VERB #NAME, but I haven't got #AN #NOUN.",
             'Is that #AN #NOUN in your #NOUN, or are you just #ADJECTIVE?',
             '#CAPITALISE #AN #NOUN in the #NOUN is worth two in the #NOUN.',
             "#RANDOM[2,That #NOUN would have been mine,And I would have been able to #VERB it, too], if it wasn't for you #ADJECTIVE #NOUNs!",
             "#DEFINE_REPEAT[1,#VERB the #NOUN]I'm #AN #NOUN! I'm #AN #NOUN! I'm #ADJECTIVE!  #CAPITALISE #REPEAT[1], #REPEAT[1]!",
             'Thou shalt not #VERB#ADJECTIVE_MAYBE #NOUNs.',
             'Why did the#ADJECTIVE_MAYBE #NOUN #VERB the#ADJECTIVE_MAYBE #NOUN?  #RANDOM[4,Because it was being penetrated by the #NOUN!,Because it was glued to the #NOUN!,To get to the other #NOUN!,Because it was stapled to the #NOUN!]',
             '#DEFINE_REPEAT[1,#VERB #AN #NOUN]To #REPEAT[1], or not to #REPEAT[1], that is the #RANDOM[2,question,#NOUN]!',
             'Early to #VERB #NOUNs, early to #VERB #NOUNs, makes a man #ADJECTIVE, #ADJECTIVE and #ADJECTIVE.',
             "#RANDOM[3,I'm sorry, but I must,I'm afraid I must,I have to] #VERB #RANDOM[3,your,my,that] #NOUN.",
             "I want#RANDOM[2,, you] to #VERB #RANDOM[2,your,my] #NOUN until it's #ADJECTIVE#RANDOM[2,, and #ADJECTIVE].",
             "We are strongly urging parents to write their state's #NOUN. If a child were to see this show's irresponsible scenes of #NOUNs and how they #VERB themselves with #NOUNs, they may think that they too are able to #VERB #AN #NOUN!",
             'Early to #VERB #NOUNs, early to #VERB #NOUNs, makes a man #ADJECTIVE, #ADJECTIVE and #ADJECTIVE.',
             '#DEFINE_REPEAT[1,#CAPITALISE #VERB #NAME]#REPEAT[1], #NAME! #REPEAT[1] like #AN #ADJECTIVE #NOUN!',
             "I want#RANDOM[2,, you] to #VERB #RANDOM[3,your,my,#NAME's]#ADJECTIVE_MAYBE #NOUN until it's #ADJECTIVE#RANDOM[4,,,,and #ADJECTIVE]!",
             'Apparently, many #NOUNs will make a #NOUN #VERB #NOUNs...',
             # "#CAPITALISE #RANDOM[2,#NAME,#AN #ADJECTIVE #NOUN] #RANDOM[4,SCANDAL,HORROR,TRAGEDY,ROMP]! #RANDOM[3,,,'#CAPITALISE #VERB the #NOUNs.' says #RANDOM[2,#NAME,#ADJECTIVE #NOUN].]",
             '#NAME summons #AN #ADJECTIVE #NOUN to #VERB #NAME!',
             "Oh yes, you can #VERB me, and you can #VERB me, and you can #VERB my #NOUN, but you won't change the way I #VERB #RANDOM[3,#NAME,my #NOUN,#NOUNs].",
             'How can someone so #ADJECTIVE #VERB #RANDOM[5,#NOUNs,#NAME,me,#ADJECTIVE #NOUNs,#AN #NOUN]?',
             "#DEFINE_REPEAT[1,#NOUNs]ATTENTION #NOUNs! You are #REPEAT[1]. Nothing but#ADJECTIVE_MAYBE #REPEAT[1].  #RANDOM[2,,You think you're #ADJECTIVE but you're not.]",
             "Is it #AN #NOUN? Is it #AN #NOUN? No, it's #RANDOM[2,#NOUN-Man!,#NAME!] More #ADJECTIVE than #AN #ADJECTIVE #NOUN, able to #VERB #ADJECTIVE #NOUNs in a single #NOUN!",
             'You are the most #ADJECTIVE #NOUN. Goodbye!']

VERBS = ['eat', 'fling', 'smell', 'love', 'hate', 'detest', 'ridicule', 'tickle', 'chase', 'get inside', 'terrify',
         'steal', 'abduct', 'sniff', 'poke', 'embarrass', 'upset', 'jump on', 'frighten', 'startle', 'laugh at',
         'taunt', 'upset', 'worry', 'kill', 'paint', 'burn', 'attack', 'pick on', 'shoot', 'look at', 'stretch',
         'spy on', 'scribble on', 'throw #NOUNs at', 'sacrifice #NOUNs to', 'make statues of', 'cuddle', 'baffle',
         'attract', 'stun', 'leap over', 'stalk', 'bounce', 'kneel before', 'scare', 'lick', 'hurl', 'trick', 'annoy',
         'loathe', 'follow', 'spit at', 'dribble on', 'clean', 'polish', 'rub', 'anaesthetise', 'conspire against',
         'stir-fry', 'boil', 'butter', 'fry eggs on', 'take photographs of', 'ignore', 'pretend to be', 'scrub',
         'roast', 'run after', 'live without', 'live with', 'sell #NOUNs to', 'hurt', 'offend', 'put up with',
         'take up arms against', 'hide behind', 'hide #NOUNs behind', 'dampen', 'adore', 'hypnotise', 'prepare',
         'compare #NOUNs with', 'sponge-bath', 'gang up on', 'snigger at', 'titter at', 'care about', 'lust after',
         'hide from', 'ride', 'eschew', 'stab', 'destroy', 'mangle', 'steal', 'talk to', 'mend', 'iron',
         'apply make-up to', 'look like', 'impersonate', 'drool over', 'sing to', 'write books about', 'feel sorry for',
         'hug', 'shred', 'spraypaint', 'maul', 'abuse', 'twist', 'kick', 'prod', 'inflate', 'decorate', 'squash',
         'argue with', 'tell lies to', 'whittle', 'drown', 'murder', 'cook', 'deep-fry', 'torture', 'arouse',
         'glower at', 'degauss', 'irradiate', 'pester', 'dissect', 'paint strange symbols on', 'carve runes on',
         'interfere with', 'disrupt', 'fill', 'secretly admire', 'kiss', 'unearth', 'bury', 'exhume',
         'take the mickey out of', 'munch', 'suck', 'cast spells at', 'summon', 'explode', 'grope', 'poison', 'taint',
         'drool over', 'petrify', 'swallow', 'digest', 'love the smell of', 'inject drugs into',
         'carry out experiments on', 'genetically mutate', 'play football with', 'smother', 'slaughter', 'dent',
         'attach #NOUNs to', 'replace', 'usurp', 'spy on', 'oppress', 'defrost', 'make jokes about', 'clout', 'bake',
         'pray for', 'hope for', 'avoid', 'keep away from', 'levitate', 'feel', 'smell like', 'flog', 'run over',
         'chat with', 'tell jokes to', 'trick', 'sketch', 'smoke', 'lose', 'give money to', 'flirt with', 'fight',
         'get into a fight with', 'do battle with', 'declare war on', 'wear', 'hoover', 'daub', 'teach', 'autograph',
         'mind', 'joust with', 'lie about', 'write a song about', 'sing a song about', 'feed', 'stumble into',
         'trip over', 'wish for', 'put the wind up', 'juggle', 'exhaust', 'turn to face', 'gaze upon', 'magnify',
         'contemplate', 'plot to kill', 'assassinate', 'trample', 'drink', 'sip', 'quaff', 'dilute', 'garotte',
         'rescue', 'drop things on', 'stand beside', 'sit on', 'hold', 'fondle', 'excrete', 'fool around with',
         'teleport', 'lunch on', 'slay', 'whip', 'enchant', 'curse', 'remove', 'hammer nails into', 'glue',
         'desalinate', 'build', 'charge towards', 'stamp on', 'campaign against', 'punch', 'hassle', 'snipe at',
         'devote a shrine to', 'headbutt', 'videotape', 'defenestrate', 'dematerialise', 'jab',
         'play Mornington Crescent with', 'squeeze', 'sacrifice', 'doubt', 'fear', 'burn', 'dye', 'tie-dye', 'abide',
         'club', 'cull', 'drill holes in', 'flip', 'invert', 'silver-plate', 'broil', 'grill', 'fool',
         'play twister with', 'sell life insurance to', 'blow raspberries at', 'manacle', 'touch',
         'make TV documentaries about', 'stamp on', 'blow up', 'fall off of', 'stand on', 'put things in',
         'get close to', 'innoculate', 'get stuck in', 'mystify', 'transmogrify', 'ambush', 'handcuff',
         'quantity-survey', 'haggle with', 'hang', 'crucify', 'hide inside', 'smuggle drugs inside', 'smuggle',
         'give birth to', 'impregnate', 'enter', 'shine torches at', 'set fire to', 'drug', 'set traps for',
         'dress up as', 'mince', 'carry', 'lift', 'levitate', 'swim with', 'chat casually with', 'disguise',
         'deny the existence of', 'pretend to #VERB', 'strangle', 'sue', 'detect', 'transform', 'embalm', 'bite',
         'pickle', 'brew up a cup of tea for', 'make friends with', 'antagonise', 'exterminate', 'go on holiday with',
         'recharge', 'spoon-feed', 'kung-fu fight', 'blow', 'flick rubber bands at', 'slobber over', 'throw sticks for',
         'shoot paintballs at', 'set fire to', 'electrify', 'electroplate', 'lift and separate', 'drag',
         'charge headlong at', 'pounce on', 'fear and loathe', 'breathe all over', 'pay attention to',
         'enter into a suicide pact with', 'handcuff', 'bludgeon', 'frame', 'catalogue', 'collect', 'walk away from',
         'spoon-feed', 'sprinkle parmesan cheese over', 'write to the government about', 'outlaw', 'breast-feed',
         'clean drains with', 'unblock sinks with', 'fall from the sky onto', 'race', 'tie-dye', 'embalm',
         'pour Jello over', 'marry', 'sculpt', 'vomit all over', 'sneeze all over', 'vaccinate', 'duplicate',
         'shelter underneath', 'have fun with', 'banish', 'exile', 'go to the pictures with', 'mentally-undress',
         'annoy the hell out of', 'play cricket with', 'roundhouse-kick', 'drop #NOUNs on', 'get blood out of',
         'get sense out of', 'gain energy from', 'tap the hidden powers of', 'get intimate with', 'imitate',
         'go for long walks with', 'give up everything for', 'ridicule', 'humiliate', 'build a house out of',
         'sing Oasis songs to', 'throw whitewash over', 'tie-dye', 'share a bed with', 'hurt', "say 'Ni!' to",
         'tell lies about', 'spread rumours about', 'smother', 'guard', 'pay careful attention to', 'fry',
         'commit suicide with', 'clamber over', 'catch nasty diseases from', 'catch rabies from', 'send postcards to',
         'flick', 'fold', 'email', 'teach calculus to', 'explain quantum mechanics to', 'make little presents for',
         'lay booby-traps for', 'identify', 'pass laws against', 'abolish', 'go out and get drunk with', 'flirt with',
         'kneel down and worship', 'cast horrified glances at', 'intimidate', 'petrify', 'do the Vulcan neck pinch on',
         'shave', 'skin', 'capture', 'feel', 'emulate', 'go on holiday with', 'make prank phone calls to',
         'go away for a dirty weekend with', 'warn small children about', 'secretly admire', 'secrete',
         'find out the truth about', 'fancy', 'talk about', 'make up terrible lies about', 'perform dubious acts upon',
         'get into bed with', 'whisper sweet nothings to', 'go for a walk with', 'place explosives around',
         'appear on television denouncing', 'complain to the council about', 'pick up satellite broadcasts with',
         'feed baby food to', 'give the kiss of life to', 'measure the dimensions of', 'take X-rays of', 'interrogate',
         'seek and destroy', 'oven-roast', 'pester', 'create stupid globals about', 'quote Monty Python at',
         'get various bodily parts stuck in', 'drown', 'hide', 'go deep-sea diving with', 'play basketball with',
         'cherish', 'find fingerprints on', 'stick sharp objects into', 'rub up against',
         'write best-selling novels about', 'call out the police to investigate', 'meddle with',
         'meddle in the affairs of', 'spread peanut butter on', 'calculate the weight of', 'weigh', 'measure',
         'bribe policemen with', 'laugh bleakly at', "cast 'turning into a newt' spells at", 'get kicks from', 'bite',
         'creep up on', 'consider', 'think about', 'blame the Second World War on', 'spill beer on',
         'appear in pantomime with', 'apologise to', 'giggle at', "say 'Tish' to", 'shout at', 'go to the cinema with',
         'make strange noises at', 'stir drinks with', 'paint Tipp-Ex on', "compare a summer's day to", 'elope with',
         'pick holes in', 'write newspaper articles about', 'pout at', 'advertise', 'play chess with', 'maul',
         'guess the weight of', 'idolise', 'gift-wrap', 'hold a national holiday in honour of', 'dowse for',
         'gibber at', 'preach at', 'make soup out of', 'take suggestive photos of', 'go shopping with',
         'pour hot soup over', 'throw buckets of whitewash over', 'really hate', 'perform major surgery on',
         'get turned on by', 'fire rockets at', 'predict the future using', 'make bad jokes about',
         'plot the downfall of', 'have an unhealthy obsession with', 'French kiss', 'give #NOUNs to',
         'wrap newspaper around', 'sprinkle salt and vinegar on',
         'do unconvincing George Formby impressions in front of', 'parse', 'enter', 'asphyxiate', 'smother',
         'regurgitate', 'grab', 'seize', 'molest', 'draw smiley faces on', 'flip tiddlywinks at',
         'take part in a government conspiracy to conceal the truth about', 'cook and eat', 'skin', 'whisk',
         'weigh up the pros and cons of', 'wallpaper', 'claim custody of', 'make love to', 'serve dinner to',
         'hum classical music at', 'spray water all over', 'dance the lambada with', 'fillet', 'gut', 'disappoint',
         'jab knitting needles into', 'hold a lighted match beneath', 'thump', 'lie in wait for', 'hollow out',
         'take a bath with', 'get high on', 'sandblast', 'drink from', 'squish', 'play kiss-chase with',
         'drive iron spikes through', 'hammer nails into', 'practice origami on', 'practice ju-jitsu on',
         'brutally assault', 'daydream about', 'dream about', 'throw caltraps beneath', 'give awards to', 'smile at',
         'blame lag on', 'horse-whip', 'act standoffishly towards', 'predict the weather using', 'waggle', 'feel like',
         'suck the innards out of', 'bleed all over', 'supply terrorists with', 'repress', 'strike matches on',
         'play Scrabble against', 'chop down the mightiest tree in the forest with', 'overlook', 'bulldoze',
         'raise money for', 'converse with', 'dine upon', 'hold up banks with', 'grab hold of', 'catch cholera from',
         'turn to stone at the sight of', 'take up residence with', 'rent', 'hire', 'parachute down onto',
         'suck all the juice out of', 'nudge', 'squabble with', 'play loud music at', 'play bass guitar at',
         'act as backing vocals to', 'get rather intimate with', 'make crop circles with',
         'commit serial killings with', 'touch', 'wink at', 'shake a stick at', 'take pot-shots at', 'fight fire with',
         'put a plaster-cast around', 'think about', 'write horoscopes for', 'ward off vampires with',
         'get stuck in a lift with', 'go ice-skating with', 'hunt', 'steal things from', "use the 'surreal' global on",
         'prepare photofits of', 'assume things about', 'jump to conclusions about', 'smear strawberry ice-cream over',
         'fiddle with', 'toy with', 'shave with', 'cut hedges with', 'stand in the rain with', 'get in the way of',
         'dump', 'metamorphose into', 'seek inspiration from', 'cocoon', 'buy your mother', 'bless', 'straddle',
         'attach electrodes to', 'kick the ground out from underneath', 'invent',
         'discover a lost Shakespeare play about', 'assimilate', 'frogmarch', "say 'Oook' to", 'take a shower with',
         'imagine what life would be like without', 'imagine a world without', 'autograph', 'hate the sight of',
         'behead', 'scratch', 'forbid', 'turn lead into', 'perform a Lycos search for',
         'write an X-Files episode about', 'make puerile jokes about', 'do a very bad impression of', 'pebble-dash',
         'scream at', 'faint at the sight of', 'save the world from', 'blame the lag on', 'make tasteless jokes about',
         'lightly grill', 'shallow-fry', 'oven-roast', 'barbecue', 'pour boiling oil over', 'collect',
         'write letters to the Times about', 'wallpaper', 'extract red mercury from', 'cure alopecia with', 'digest',
         'worship', 'do unspeakable deeds with', 'slice', 'swap two boxes of Daz Automatic for', 'bully', 'beat up',
         'go to the market to buy', 'taste', "hum 'Colonel Bogey' at", 'wolf-whistle at', 'whistle for',
         'buy shares in', 'invest in', 'get upset by', 'make wine out of', 'empty cans of alphabet soup over',
         'tie scarves around', 'balance things on top of', 'pine for', 'regurgitate', 'go for rides on',
         'smear mustard on', 'drool at the thought of', 'clean toilets with', 'stretch', 'peck', 'give lovebites to',
         'outrank', 'pull rank on', 'predict the weather using', 'practise martial arts on', 'look down on',
         'get completely confused by', 'get utterly thrown by', 'disorientate', 'magnetise', 'cast Magic Missile at',
         'lathe', 'regret having been involved with', 'deny any connection with', 'lightly toast',
         'ask awkward questions of', 'parade up and down in front of', 'pedal', 'pester', 'send begging letters to',
         'do revolting things to', 'snag', 'peel grapes for', 'throw stuff at', 'excuse', 'get a kick out of',
         'get a perverse pleasure out of', 'throw knickers at', 'go drinking with', 'pull', 'push', 'make risotto with',
         'damage', 'encircle', 'enrage', 'gag', 'suspect', 'break the ice with', 'get the ice off of windscreens with',
         'break the ice at parties with', 'run around after', 'quibble over', 'quash', 'quote stock prices at',
         'cry over', 'cry about', "cry 'Wolf!' at the sight of", 'experience extreme sexual tension around', 'meet',
         'look bigger than', 'stand behind', 'slap wallpaper paste onto', 'generate electricity from', 'generate',
         'tax', 'kid', 'gush about', 'flatter', 'run a bar-code-reader over', 'eradicate', 'sing in harmony with',
         'mention your sexual conquest of', 'send parcels to', "send Valentine's cards to", 'send love letters to',
         'send the boys round to deal with', 'perform stand-up comedy at', 'compare thee to', 'suck and blow',
         'take artistic photos of', 'make a short documentary about', 'hang onto', 'mix drinks in', 'stir drinks with',
         'have inane conversations with', 'hang wind-chimes from', 'visit', 'stand very close to', 'speak Swedish to',
         'do a bit of work on', 'run away from', 'run towards', 'climb', 'step on', "say 'I Kiss You!' to", 'jump over',
         'jump out in front of', 'erect', 'erect statues of', 'swim with', 'go punting on the Cam with', 'fix',
         'recline on', 'shoot silver bullets at', 'believe that Stonehenge was built by',
         'believe that the pyramids were built by', 'make matters worse with', 'go to the toilet on', 'go to work on',
         'reflect light from', 'crush', 'claw', "believe it's not", 'thrash', 'set up an e-commerce site that sells',
         'swap two #NOUNs for', 'graft extra limbs onto', 'whisper to', 'go barter-shopping with', 'remix', 'balance',
         'balance #NOUNs on top of', 'wobble', 'scare #NOUNs with', 'scar', 'bleach', 'disinfect', 'counteract',
         'enhance', 'ask #NAME about', 'tell #NAME about', 'take', 'steal the duvet from', 'steal #NOUNs from',
         'ask questions about', 'ask #NAME for', 'violate', 'pluck', 'drive', 'measure the width of',
         'measure the height of', 'spit', 'dust', 'clip', 'click on', 'hit on', 'suck on', 'braise',
         'go out on the town with', 'bother', 'apply Goth make-up to', 'choose', 'choose to #VERB',
         'scare #NOUNs away with', 'trim the edges off of', 'snip the corners off of', 'actually #VERB',
         'pick fights with', 'pick', 'object to', 'obstruct', 'lightly squeeze', 'open', 'operate on', 'operate',
         'give a damn about', 'tug', 'tug on', 'turn', 'turn to', 'become', 'bring', 'build', 'buy', 'clothe',
         'forgive', 'forget', 'knit', 'seek', 'debug', 'put an advert in the paper for', 'come back to haunt', 'buckle',
         'supply arms to', 'reflect death-rays with', 'beanpole', 'projectile-vomit at', 'project', 'batter', 'bat',
         'exchange', 'exchange #NOUNs for', 'bug', 'keep up with', 'keep', 'indicate', 'plant', 'pepper', 'sever',
         'erect a plastic dome over', 'write about', 'return to', 'pour parsley sauce over', 'cross', 'crochet', 'crop',
         'crown', 'croon at', 'crow over', 'stick sellotape to', 'stick #NOUNs to', 'open supermarkets with', 'tear',
         'operate heavy machinery under the influence of', 'snap', 'snare', 'shake', 'shame', 'share', 'shape',
         'shatter', 'shackle', 'shadow', 'hate the smell of', 'spray', 'sprain', 'spring', 'spear',
         'receive illegal cable TV on', 'neigh at', 'spit #NOUNs at', 'crack', 'silence', 'develop an allergy to',
         'launch', 'launch #NOUNs at', 'trebuchet', 'nip off and get', 'hold a geiger counter to', 'sigh wearily at',
         'write to', 'wring', 'give mouth-to-mouth resuscitation to', 'overtake', 'over-water', 'overrule', 'overthrow',
         'demand', 'request', 'battle', 'pound', 'give a job to', 'act nicely to', 'build a wall in front of',
         'apprehend', 'make breakfast for', 'sneeze at', 'annul', 'defeat', 'contract out', 'render', 'prize', 'prise',
         'print', 'primp', 'take pride in', 'believe', 'belittle', 'get #NAME mixed up with', 'mistake #NOUN for',
         'need to know about', 'mislay', 'misplace', 'wonder why it always rains on', 'measure the diameter of',
         'crash into', 'fluff up', 'flush', 'flutter', 'defuse', 'deaden', 'deal', 'demean', 'borrow', 'ward off',
         'write an SQL database to store details about', 'freshen my armpits with', 'shock', 'shop', 'manhandle',
         'act pleased to see', 'transform into', 'bang', 'bang on about', 'hit', 'train', 'bloody', 'burgle', 'warp',
         'call', 'cobble together', 'measure the inside-leg of', 'accidentally #VERB', 'care for', 'carefully #VERB',
         'harvest', 'choose #NOUN over', 'babble at', 'babysit', 'lance', 'forbid entry to', 'forge', 'get eaten by',
         'share a cigarette with', 'share #NOUN with', 'gamble on', 'hold a vigil for', 'banner-advertise',
         'search the Web for', 'search for', 'search', 'hob-nob with', 'abuse', 'abuse #NAME with', 'squawk at',
         'write bestsellers about', 'skewer', 'ponder', 'model', 'deep-freeze', 'beckon to', 'smell like',
         'squirt juices over', 'jangle', 'ponder', 'pay fifty quid for half an hour with', 'ride', 'get bored by',
         'spill the beans about', 'invoke rule 4278(b) against', "put hallowe'en masks on", 'pay for',
         'play the saxophone at', 'whistle The Dambusters March at', 'offer jellybabies to',
         'rub strawberry ice-cream into', 'fit a catalytic convertor to', 'loan out', 'faint at the sight of',
         'have three-in-a-bed romps with', 'spend hours on the phone to', 'run in circles around', 'fly alongside',
         'faint at the sight of', 'hyperventilate at the sight of', 'spam Usenet with postings about',
         'apply sticky-tape to', 'have recurring nightmares about', 'spin', 'keep loose change in', 'stuff',
         'make gravy from', 'go back to', 'give birth to', 'wire electrodes to', 'gain super-powers from', 'humiliate',
         'poke holes in', 'pick up BBC Radio Four on', 'order a pizza topped with', 'salivate over',
         'go ram-raiding with', 'topple', 'snuggle up to', 'pay tax on', 'grind', 'sidle towards', 'repulse',
         'resist the charms of', 'avoid thinking about', 'behead', 'remove the upper half of', 'wave a magic wand at',
         'turn invisible when in the presence of', 'set a match to', "shout 'Crackerjack!' at",
         'recite verses from the Bible at', 'read poetry to', 'create antimatter from', 'shriek at', 'tapdance on',
         'misunderstand', 'bait badgers with', 'catch fish with', 'maintain Web pages about', 'tell your friends about',
         'cull', 'give piggy-backs to', 'darken', 'pulp', 'watch', 'watch over', 'guard', 'protect', 'slice',
         'avoid paying for', 'bury treasure beneath', 'catch tonsilitis from', 'cure the common cold with', 'defend',
         'drop-kick', 'implode', 'double-glaze', 'do Sean Connery impressions at', 'snuggle', 'paint the Union Jack on',
         'poke and prod', 'find great amusement in', 'make mad, passionate love to', 'lend money to',
         'pay good money for', 'bubble-wrap', 'ask to see', 'breathalyse', 'interfere with', 'choke to death on',
         'deafen', 'blind', 'play leap-frog with', 'laugh in the face of', 'pour scorn on', 'pour gravy on',
         'seek inspiration from', 'go out and get drunk with', 'tell knock-knock jokes to', 'make Airfix models of',
         'massage', 'knock some sense into', 'vapourise', 'smite', 'mimic', 'charm', 'find solace in',
         'speak French to', 'snog', "sing 'Mint Car' to", 'sing Christmas carols to', 'go bungee-jumping with',
         'evolve into', 'find out everything there is to know about', 'write a fanzine about', 'loom over', 'prey on',
         'bore the pants off', 'tell golfing anecdotes to', 'eat nothing but', 'laugh insanely at', 'applaud',
         'make a stand against', 'perform medical experiments on', 'look down on', 'feed and water', 'look after',
         'amuse', 'entertain', 'fit inside', 'have impure thoughts about', 'wish for', 'sprinkle sparkly stuff over',
         'crumple', 'request an audience with', 'yell at', "prove Einstein's Unified Field Theory with",
         'stir coffee with', 'throw Jello at', 'play in Jello with', 'love the taste of', 'make scary noises at',
         'get the better of', 'outwit', 'smarm up to', 'caress', 'mug', 'rob', 'hold', 'weigh', 'repulse',
         'have a phobia about', 'get all soppy over', 'juggle with', 'fawn over', 'spit coffee at',
         'mop up kitchen spills with', 'find endless amusement in', 'study the behaviour of',
         'predict the behaviour of', 'get high on', 'glaze', 'varnish', 'improve', 'run around naked with',
         'carve little figurines of', 'plug RS232 cables into', 'get trapped inside', 'liquify', 'stare at',
         'salivate at the sight of', 'feed Soylent Green to', 'go joyriding in', 'smash shop windows with',
         'staple memos to', 'throw knives at', 'pull rabbits out of', 'hypnotise', 'barbecue',
         'prescribe phenoxymethylpenicillin to', 'throw crumbs to', 'peel a banana for', 'exorcise',
         'feed Wine Gums to', 'feed #NOUNs to', 'calculate logarithms with', 'prove the existence of God using',
         'duel with', 'get a bad feeling about', 'cross-examine', 'appear in panto with', 'spend all your money on',
         'play Psychological Ju-Jitsu against', 'spank', 'seize', 'touch', 'slap', 'work for', 'enslave',
         'take tea with', 'flap', 'travel on the London Underground with', 'break the silence with', 'quiz',
         "say 'gack ack ack gack-ack ack ack-gack gack' to", 'shaft', 'straddle', 'weigh',
         'go to the ends of the earth in search of', 'find considerable amusement in', 'get drunk on',
         'sprinkle glitter on', 'play Magic: The Gathering with', 'rub up against', 'go to gigs with',
         'scream blue murder at', 'get into a bath with', 'understudy', 'staple astroturf to',
         'attach bits of bacon to', 'play air-guitar at', 'feed crisps to', 'wish for', 'spray deodorant on', 'tease',
         'hanker for', 'spurn the advances of', 'feed Jelly Babies to', 'vomit over', 'outwit', 'shrink', 'enlarge',
         'trace', 'hurl insults at', 'throw hoops at', 'dance the lambada with', 'discuss religion with',
         'install Windows 95 on', 'reheat', 'get scared by', 'get turned on by', 'running-slap', 'miss', 'stone',
         'slip inside', 'christen', 'fit inside', 'slip up on', 'surround', 'snog', 'outgun', 'deflate',
         'corner the market on', 'defaecate on', 'spear', 'sell your soul to', 'gather', 'usurp', 'twist', 'disembowel',
         'run errands for', 'clone', 'dice', 'see', 'notice', 'increase public awareness of', 'prod',
         'have TinySex with', 'smooch', 'nibble', 'withdraw what was said about', 'hyperventilate at the sight of',
         'pop', 'prick', 'obey', 'paint', 'pebble-dash', 'fight', 'play a computer game about', 'emit', 'goad', 'rile',
         'unsettle', 'disturb', 'iron', 'attract a chicken with', 'snack upon', 'ram-raid', 'play pinball with',
         'bathe', 'take a hedge-trimmer to', 'tweak', 'dowse for water with', 'tremble at the sight of',
         'pay good money for', 'starve', 'mock', 'jinx', 'become aroused by', 'make thrusting motions against', 'feel',
         'tie belts around', 'tip waiters with', 'spend the night in', 'get locked inside', 'get up to no good with',
         'go ram-raiding with', "appear on 'Stars In Their Eyes' as", 'undress in front of', 'feel like',
         'tell your parents about', 'counter-spell', 'give a sermon on the evils of', 'raytrace', 'amuse', 'prey on',
         'cure cancer with', 'let go of', 'fight in two world wars for', 'squeeze Primula onto', 'rub Savlon into',
         'checkmate', 'paint lines on', 'get mistaken for', 'slurp', 'break the light-speed barrier with',
         'poke and prod', 'envy', 'quote the bible at', 'go to parties with', 'rend', 'find solace in',
         'get a sun-tan from', 'think the sun shines out of', 'entertain guests with', 'move in with', 'listen to',
         'extract vitamin D from', 'save', 'tell the papers about', 'gaze adoringly at', 'karate chop',
         'throw #NOUNs at', 'depress', 'go to film premieres with', 'gas', 'get depressed by',
         'tell your ex-partner about', 'elope with', 'strip-search', 'tap', 'grease', 'go for a picnic with',
         'act like', 'counter the Tait-Davis field with', 'get engaged to', 'snip', 'smell like', 'taste like',
         'feel like', 'develop a taste for', 'admonish', 'perform root-canal work with', 'hide beneath', 'wiggle',
         'hospitalise', 'hop up onto', 'throw salt over', 'get married to', "sing 'My Way' at", 'sell your soul to',
         'subtly adjust', 'teleport', 'sing drunkenly at', 'tell lightbulb jokes to', 'spill coffee on', 'fling',
         'have a one-night stand with', 'act provocatively toward', 'spam', 'recite the Parrot Sketch at', 'unbuckle',
         "write a stern letter to 'Points of View', complaining about", 'bend', 'bend over backwards for', 'floss',
         'have all manner of exciting adventures with', 'inspire', 'bore', 'predict Grand National winners with',
         'select', 'lend your lawnmower to', 'bow and scrape to', 'lie in wait for', 'test cosmetics on',
         'look in the mirror and see', 'yodel at', 'torture', 'torment', 'harness the power of lightning with',
         'achieve perpetual motion using', 'focus on', 'resist', 'take over the world with', 'butt', 'vacuum-pack',
         'go out with', 'run the marathon with', 'repair toasters with', 'repair', 'datestamp',
         'go on a blind date with', 'join', 'walk down the aisle with', 'jump-start', 'bare all to', 'detonate',
         'unplug', 'visualise', 'knight', 'hatch', "spoil the ambassador's guests with", 'blush at the sight of',
         'entrance', 'bewitch', 'stick a red-hot poker up', 'produce bunches of flowers from',
         'sprinkle talcum powder on', 'throw itching powder at', 'place whoopie-cushions beneath',
         'exchange two boxes of Brand X washing powder for', 'nullify', 'regenerate', 'hang tinsel from', 'inseminate',
         'entrap', 'enlarge', 'herd', 'rustle', 'hang from', 'play Quake against', 'extract the elixir of life from',
         'tsk', 'recite limericks at', 'arse around with', 'plunge into', 'clasp', 'grasp', 'perform lap-dances for',
         'pour cheese sauce over', 'strangle', 'disrobe in front of', 'get a tattoo of', 'cough at',
         'take bites out of', 'peck', "write an 'Arena' simulation of", 'feel inferior to',
         'dive from a great height onto', 'badger', 'cherish', 'toy with', 'date', 'applaud', 'mail-order',
         'ask Father Christmas for', 'bore', 'banter with', 'exchange witty bon mots with', 'amuse',
         'fart in the general direction of', 'sidestep', 'step over', 'run away with', 'establish the gender of',
         'bottle', 'grit', 'ruin', 'touch', 'crash', 'moon at', 'act arrogantly towards',
         'write magazine articles about', 'access the Internet via', 'flick', 'condone', 'wonder about', 'throttle',
         'starve', 'choke', 'over-feed', 'transubstantiate', 'eviscerate', 'forage for', 'pour curry sauce over',
         'encourage', 'stare aghast at', 'cower in abject terror from', 'write sonnets about', 'summon Cthulhu with',
         'offer Polos to', 'enhance exam revision with', 'have a holiday romance with', 'win friends and influence',
         'regret the actions of', 'have an affair with', 'graze', 'apply ointment to', 'bribe',
         'do unspeakable things to', 'fret over', 'worry about', 'spend a lot of money on', 'waste time with',
         'apply black nail-varnish to', 'go badger-baiting with', 'fire blow-pipe darts at',
         'flick little balls of rolled-up newspaper at', 'drill for', 'blow', 'paint a mural of',
         'play Wordzap against', 'agonise about', 'span', 'find flaws in', 'conquer', 'launch a crusade against',
         'decorate my garden with', 'engorge', 'pursue', 'freeze', 'put compost on', 'circumcise', 'herd',
         'remind people of', 'throw caution to', 'find amusement in', 'extrude', 'check the millennium-compliance of',
         'question the purpose of', 'tame', 'drape tinsel over', 'strike poses with', 'circumcise', 'demolish',
         'get paid to #VERB', 'balance #NOUNs on top of', 'smear lipstick over',
         "continually use the 'random surrealism generator' in the hope of getting something about",
         'find weak double-entendres in', 'genetically modify', 'do something horrible to', 'photocopy',
         'stitch buttons onto', 'warn Will Robinson about', 'get three black mana from', 'contract brain damage from',
         "say 'semprini' to", 'cheer the arrival of', 'bear', 'dance with', 'grin impishly at', 'sing ballads at',
         'serenade', 'slash', 'carve a scary face in', 'put barcodes on', 'date-stamp', 'play tennis with',
         'sleep under', 'work with', 'work for', 'work on', 'search eBay for', 'shut up about', 'shunt', 'rotate',
         'twist', 'unbalance', 'unsettle', 'disturb', 'inject arsenic into', 'inject morphine into', 'respray',
         'sell drugs to', 'auction', 'dispose of radioactive waste by dumping it in',
         'get shirts whiter than white with', 'flirt outrageously with', 'spit bile at', 'pump', 'tempt', 'covet',
         'wall-mount', 'mime at', 'chop down trees with', 'suspend', 'take tea with', 'read the news to',
         'teach algebra to', 'issue a writ against', 'hammer in nails with', 'sing a merry song about',
         'ask the Prime Minister about', 'hold a referendum on', 'flagellate', 'break tragic news to',
         'kill people with', 'resurrect the dead with', 'make people laugh with', 'scare people with',
         'baffle scientists with', 'squint at', 'descend onto', 'hang from the ceiling and swing over',
         'hang upside-down over', 'hang Christmas decorations from', 'chill', 'take chunks out of', 'strip', 'paint',
         'dress up as', 'whine about', 'cower at the sight of', 'resist the charms of', 'disconnect']



#!/usr/bin/env python

#############################################################################
#    surrealism.py - Surreal sentence and error message generator
#    Copyright (C) 2014  Ian Havelock
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#############################################################################
#
# This is a derivative work (used with permission) from www.ravenblack.net
# Credit also goes to Kevan Davis on whose work the surrealism generator at
# Ravenblack.net is based on...

#############################################################################

__all__ = ['show_faults', 'show_sentences', 'getfault', 'getsentence', 'version',
           'sentence_test', 'fault_test', 'show_sentences', 'show_faults']

# IMPORTS ###################################################################

import sqlite3
from pydblite import Base

import random
import pkg_resources

# PARTICULAR IMPORTS ########################################################

from pkg_resources import resource_filename

# CONSTANTS #################################################################

# CONN = sqlite3.connect(resource_filename(__name__, 'surrealism.sqlite'))
CONN = Base("surrealism.sqlite")
if CONN.exists():
    CONN.open()


# VARIABLES #################################################################


# CLASSES ###################################################################


#############################################################################

#  EXTERNAL METHODS BELOW

def version():
    """Returns the current version of the Surrealism module."""

    return pkg_resources.require('surrealism')[0].version


def showfaults():
    """
    This exists for backwards compatibility
    :return:
    """
    output = show_faults()
    return output


def show_faults():
    """
    Return all valid/active faults ordered by ID to allow the user to pick and choose.

    :return:  List of Tuples where the Tuple elements are:  (fault id, fault template)
    """

    _query = "SELECT fau_id, fault FROM surfaults WHERE fau_is_valid = 'y' ORDER BY fau_id ASC"
    result = __execute_sql_all(_query)
    return result


def showsentences():
    """
    This exists for backwards compatibility
    :return:
    """
    output = show_sentences()
    return output


def show_sentences():
    """
    Return all valid/active sentences ordered by ID to allow the user to pick and choose.

    :return:  Dict containing the sentence ID as the key and the sentence structure as the value.
    """

    _query = "SELECT sen_id, sentence FROM sursentences WHERE sen_is_valid = 'y' ORDER BY sen_id ASC"
    result = __execute_sql_all(_query)

    response_dict = {}
    for row in result:
        response_dict[row[0]] = row[1]
    return response_dict


def faulttest():
    """
    This exists for backwards compatibility
    :return:
    """
    output = fault_test()
    return output


def fault_test():
    """Returns 1 instance of each programming fault for testing purposes."""

    _counts = __get_table_limits()
    max_num = _counts['max_faults']
    counter = 0
    list_of_tuples = []
    _fau_result = None

    while counter < max_num:
        counter += 1
        _fault = __get_fault(_counts, fault_id=counter)
        fau_id = _fault[1]

        if _fault[0] == 'n':
            _fau_result = "Fault is DISABLED - ignoring..."

        if _fault[0] == 'y':
            _fau_result = __process_sentence(_fault, _counts)

        list_of_tuples.append((fau_id, _fau_result))
    return list_of_tuples


def sentencetest():
    """
    This exists for backwards compatibility
    :return:
    """
    output = sentence_test()
    return output


def sentence_test():
    """Return 1 random version of each sentence to test sentence structure."""

    _counts = __get_table_limits()
    max_num = _counts['max_sentences']
    counter = 0
    list_of_tuples = []
    _sen_result = None

    while counter < max_num:
        counter += 1
        _sentence = __get_sentence(_counts, sentence_id=counter)
        sen_id = _sentence[1]

        if _sentence[0] == 'n':
            _sen_result = "Sentence is DISABLED - ignoring..."

        if _sentence[0] == 'y':
            _sen_result = __process_sentence(_sentence, _counts)

        list_of_tuples.append((sen_id, _sen_result))
    return list_of_tuples


def getfault(fault_id=None):
    output = get_fault(fault_id)
    return output


def get_fault(fault_id=None):
    """Retrieve a randomly-generated error message as a unicode string.

    :param fault_id:

        Allows you to optionally specify an integer representing the fault_id
        from the database table.  This allows you to retrieve a specific fault
        each time, albeit with different keywords."""

    _counts = __get_table_limits()
    _result = None
    _id = 0

    try:
        if isinstance(fault_id, int):
            _id = fault_id
        elif isinstance(fault_id, float):
            print("""ValueError:  Floating point number detected.
                  Rounding number to 0 decimal places.""")
            _id = round(fault_id)
        else:
            _id = random.randint(1, _counts['max_faults'])

    except ValueError:
        print("ValueError:  Incorrect parameter type detected.")

    if _id <= _counts['max_faults']:
        _fault = __get_fault(_counts, fault_id=_id)
    else:
        print("""ValueError:  Parameter integer is too high.
              Maximum permitted value is {0}.""".format(str(_counts['max_faults'])))
        _id = _counts['max_faults']
        _fault = __get_fault(_counts, fault_id=_id)

    if _fault is not None:
        while _fault[0] == 'n':
            if _id is not None:
                _fault = __get_fault(_counts, None)
            else:
                _fault = __get_fault(_counts, _id)
        if _fault[0] == 'y':
            _result = __process_sentence(_fault, _counts)
        return _result
    else:
        print('ValueError: _fault cannot be None.')


def getsentence(sentence_id=None):
    output = get_sentence(sentence_id)
    return output


def get_sentence(sentence_id=None):
    """Retrieve a randomly-generated sentence as a unicode string.

    :param sentence_id:

        Allows you to optionally specify an integer representing the sentence_id
        from the database table.  This allows you to retrieve a specific
        sentence each time, albeit with different keywords."""

    _counts = __get_table_limits()
    _result = None
    _id = 0

    try:
        if isinstance(sentence_id, int):
            _id = sentence_id
        elif isinstance(sentence_id, float):
            print("""ValueError:  Floating point number detected.
                  Rounding number to 0 decimal places.""")
            _id = round(sentence_id)
        else:
            _id = random.randint(1, _counts['max_sentences'])

    except ValueError:
        print("ValueError:  Incorrect parameter type detected.")

    if _id <= _counts['max_sentences']:
        _sentence = __get_sentence(_counts, sentence_id=_id)
    else:
        print("""ValueError:  Parameter integer is too high.
              Maximum permitted value is {0}.""".format(str(_counts['max_sentences'])))
        _id = _counts['max_sentences']
        _sentence = __get_sentence(_counts, sentence_id=_id)

    if _sentence is not None:
        while _sentence[0] == 'n':
            if _id is not None:
                # here we delibrately pass 'None' to __getsentence__ as it will
                _sentence = __get_sentence(_counts, None)
            else:
                _sentence = __get_sentence(_counts, _id)
        if _sentence[0] == 'y':
            _result = __process_sentence(_sentence, _counts)
        return _result
    else:
        print('ValueError: _sentence cannot be None.')


#############################################################################

#  INTERNAL METHODS BELOW

def __execute_sql_all(query):
    cursor = CONN.cursor()

    _query = query
    cursor.execute(_query)
    return cursor.fetchall()


def __execute_sql_one(query):
    cursor = CONN.cursor()

    _query = query
    cursor.execute(_query)
    return cursor.fetchone()


def __get_fault(_counts, fault_id=None):
    """Let's fetch a random fault that we then need to substitute bits of...
    :param _counts:
    :param fault_id:
    """

    # First of all we need a cursor and a query to retrieve our ID's
    _query = "SELECT fau_id FROM surfaults"
    check_result = __execute_sql_all(_query)

    # declare an empty list to be populated below
    id_list = []
    _id_to_fetch = None

    for row in check_result:
        id_list.append(row[0])

    if fault_id is not None:
        if type(fault_id) is int:
            _id_to_fetch = fault_id
    else:
        _id_to_fetch = random.randint(1, _counts['max_faults'])

        while _id_to_fetch not in id_list:
            _id_to_fetch = random.randint(1, _counts['max_faults'])

    _query = "select * from surfaults where fau_id = {0}".format(_id_to_fetch)
    result = __execute_sql_one(_query)

    return result


def __get_sentence(_counts, sentence_id=None):
    """Let's fetch a random sentence that we then need to substitute bits of...
    @
    :param _counts:
    :param sentence_id:
    """

    # First of all we need a cursor and a query to retrieve our ID's
    query = "SELECT sen_id FROM sursentences"

    # Now we fetch the result of the query and save it into check_result
    check_result = __execute_sql_all(query)

    # declare an empty list to be populated below
    id_list = []
    _id_to_fetch = None

    # Populate the id_list variable with all of the ID's we retrieved from the database query.
    for row in check_result:
        id_list.append(row[0])

    if sentence_id is not None:
        if type(sentence_id) is int:
            _id_to_fetch = sentence_id
    else:
        _id_to_fetch = random.randint(1, _counts['max_sentences'])

        while _id_to_fetch not in id_list:
            _id_to_fetch = random.randint(1, _counts['max_sentences'])

    _query = "select * from sursentences where sen_id = {0}".format(_id_to_fetch)
    _result = __execute_sql_one(_query)

    return _result


def __get_verb(_counts):
    """Let's fetch a VERB
    :param _counts:
    """
    check_query = "SELECT verb_id FROM surverbs"
    check_result = __execute_sql_all(check_query)

    id_list = []
    for row in check_result:
        id_list.append(row[0])

    _rand = random.randint(1, _counts['max_verbs'])

    while _rand not in id_list:
        _rand = random.randint(1, _counts['max_verbs'])

    _query = "select * from surverbs where verb_id = {0}".format(_rand)
    _result = __execute_sql_one(_query)

    return _result[1]


def __get_noun(_counts):
    """Let's fetch a NOUN from the database...
    :param _counts:
    """

    check_query = "SELECT noun_id FROM surnouns"
    check_result = __execute_sql_all(check_query)

    id_list = []
    for row in check_result:
        id_list.append(row[0])

    _rand = random.randint(1, _counts['max_nouns'])

    while _rand not in id_list:
        _rand = random.randint(1, _counts['max_nouns'])

    _query = "select * from surnouns where noun_id = {0}".format(_rand)
    _result = __execute_sql_one(_query)

    return _result[1]


def __get_adjective(_counts):
    """Let's fetch an ADJECTIVE from the database...
    :param _counts:
    """

    check_query = "SELECT adj_id FROM suradjs"
    check_result = __execute_sql_all(check_query)

    id_list = []
    for row in check_result:
        id_list.append(row[0])

    _rand = random.randint(1, _counts['max_adjectives'])

    while _rand not in id_list:
        _rand = random.randint(1, _counts['max_adjectives'])

    _query = "select * from suradjs where adj_id = {0}".format(_rand)
    _result = __execute_sql_one(_query)

    return _result[1]


def __get_name(_counts):
    """Let's fetch a NAME from the database...
    :param _counts:"""

    check_query = "SELECT name_id FROM surnames"
    check_result = __execute_sql_all(check_query)

    id_list = []
    for row in check_result:
        id_list.append(row[0])

    _rand = random.randint(1, _counts['max_names'])

    while _rand not in id_list:
        _rand = random.randint(1, _counts['max_names'])

    _query = "select * from surnames where name_id = {0}".format(_rand)
    _result = __execute_sql_one(_query)

    return _result[1]


def __get_table_limits():
    """Here we simply take a count of each of the database tables so we know our
    upper limits for our random number calls then return a dictionary of them
    to the calling function..."""

    _table_counts = {
        'max_adjectives': 0,
        'max_names': 0,
        'max_nouns': 0,
        'max_sentences': 0,
        'max_faults': 0,
        'max_verbs': 0
    }

    query = 'SELECT count(*) FROM suradjs'
    _table_counts['max_adjectives'] = __execute_sql_one(query)
    _table_counts['max_adjectives'] = _table_counts['max_adjectives'][0]

    query = 'SELECT count(*) FROM surnames'
    _table_counts['max_names'] = __execute_sql_one(query)
    _table_counts['max_names'] = _table_counts['max_names'][0]

    query = 'SELECT count(*) FROM surnouns'
    _table_counts['max_nouns'] = __execute_sql_one(query)
    _table_counts['max_nouns'] = _table_counts['max_nouns'][0]

    query = 'SELECT count(*) FROM sursentences'
    _table_counts['max_sentences'] = __execute_sql_one(query)
    _table_counts['max_sentences'] = _table_counts['max_sentences'][0]

    query = 'SELECT count(*) FROM surfaults'
    _table_counts['max_faults'] = __execute_sql_one(query)
    _table_counts['max_faults'] = _table_counts['max_faults'][0]

    query = 'SELECT count(*) FROM surverbs'
    _table_counts['max_verbs'] = __execute_sql_one(query)
    _table_counts['max_verbs'] = _table_counts['max_verbs'][0]

    return _table_counts


def __process_sentence(_sentence_tuple, _counts):
    """pull the actual sentence from the tuple (tuple contains additional data such as ID)
    :param _sentence_tuple:
    :param _counts:
    """

    _sentence = _sentence_tuple[2]

    # now we start replacing words one type at a time...
    _sentence = __replace_verbs(_sentence, _counts)

    _sentence = __replace_nouns(_sentence, _counts)

    _sentence = ___replace_adjective_maybe(_sentence, _counts)

    _sentence = __replace_adjective(_sentence, _counts)

    _sentence = __replace_names(_sentence, _counts)

    # here we perform a check to see if we need to use A or AN depending on the
    # first letter of the following word...
    _sentence = __replace_an(_sentence)

    # replace the new repeating segments
    _sentence = __replace_repeat(_sentence)

    # now we will read, choose and substitute each of the RANDOM sentence tuples
    _sentence = __replace_random(_sentence)

    # now we are going to choose whether to capitalize words/sentences or not
    _sentence = __replace_capitalise(_sentence)

    # here we will choose whether to capitalize all words in the sentence
    _sentence = __replace_capall(_sentence)

    # check for appropriate spaces in the correct places.
    _sentence = __check_spaces(_sentence)

    return _sentence


def __replace_verbs(_sentence, _counts):
    """Lets find and replace all instances of #VERB
    :param _sentence:
    :param _counts:
    """

    if _sentence is not None:
        while _sentence.find('#VERB') != -1:
            _sentence = _sentence.replace('#VERB', str(__get_verb(_counts)), 1)

            if _sentence.find('#VERB') == -1:
                return _sentence
        return _sentence
    else:
        return _sentence


def __replace_nouns(_sentence, _counts):
    """Lets find and replace all instances of #NOUN
    :param _sentence:
    :param _counts:
    """

    if _sentence is not None:
        while _sentence.find('#NOUN') != -1:
            _sentence = _sentence.replace('#NOUN', str(__get_noun(_counts)), 1)

            if _sentence.find('#NOUN') == -1:
                return _sentence

        return _sentence
    else:
        return _sentence


def ___replace_adjective_maybe(_sentence, _counts):
    """Lets find and replace all instances of #ADJECTIVE_MAYBE
    :param _sentence:
    :param _counts:
    """

    _random_decision = random.randint(0, 1)

    if _sentence is not None:

        while _sentence.find('#ADJECTIVE_MAYBE') != -1:

            if _random_decision % 2 == 0:
                _sentence = _sentence.replace('#ADJECTIVE_MAYBE',
                                              ' ' + str(__get_adjective(_counts)), 1)
            elif _random_decision % 2 != 0:
                _sentence = _sentence.replace('#ADJECTIVE_MAYBE', '', 1)

            if _sentence.find('#ADJECTIVE_MAYBE') == -1:
                return _sentence
        return _sentence
    else:
        return _sentence


def __replace_adjective(_sentence, _counts):
    """Lets find and replace all instances of #ADJECTIVE
    :param _sentence:
    :param _counts:
    """

    if _sentence is not None:

        while _sentence.find('#ADJECTIVE') != -1:
            _sentence = _sentence.replace('#ADJECTIVE',
                                          str(__get_adjective(_counts)), 1)

            if _sentence.find('#ADJECTIVE') == -1:
                return _sentence
        return _sentence
    else:
        return _sentence


def __replace_names(_sentence, _counts):
    """Lets find and replace all instances of #NAME
    :param _sentence:
    :param _counts:
    """

    if _sentence is not None:

        while _sentence.find('#NAME') != -1:
            _sentence = _sentence.replace('#NAME', str(__get_name(_counts)), 1)

            if _sentence.find('#NAME') == -1:
                return _sentence
        return _sentence
    else:
        return _sentence


def __replace_an(_sentence):
    """Lets find and replace all instances of #AN
    This is a little different, as this depends on whether the next
    word starts with a vowel or a consonant.

    :param _sentence:
    """

    if _sentence is not None:
        while _sentence.find('#AN') != -1:
            _an_index = _sentence.find('#AN')

            if _an_index > -1:
                _an_index += 4

                if _sentence[_an_index] in 'aeiouAEIOU':
                    _sentence = _sentence.replace('#AN', str('an'), 1)
                else:
                    _sentence = _sentence.replace('#AN', str('a'), 1)

            if _sentence.find('#AN') == -1:
                return _sentence
        return _sentence
    else:
        return _sentence


def __replace_random(_sentence):
    """Lets find and replace all instances of #RANDOM
    :param _sentence:
    """

    _sub_list = None
    _choice = None

    if _sentence is not None:

        while _sentence.find('#RANDOM') != -1:

            _random_index = _sentence.find('#RANDOM')
            _start_index = _sentence.find('#RANDOM') + 8
            _end_index = _sentence.find(']')

            if _sentence.find('#RANDOM') is not None:
                _sub_list = _sentence[_start_index:_end_index].split(',')

                _choice = random.randint(1, int(_sub_list[0]))
                # _sub_list[_choice]

            _to_be_replaced = _sentence[_random_index:_end_index + 1]
            _sentence = _sentence.replace(_to_be_replaced,
                                          _sub_list[_choice], 1)

            if _sentence.find('#RANDOM') == -1:
                return _sentence

        return _sentence
    else:
        return _sentence


def __replace_repeat(_sentence):
    """
    Allows the use of repeating random-elements such as in the 'Ten green bottles' type sentences.

    :param _sentence:
    """

    # USE SENTENCE_ID 47 for testing!

    _repeat_dict = {}

    if _sentence is not None:

        while _sentence.find('#DEFINE_REPEAT') != -1:
            _begin_index = _sentence.find('#DEFINE_REPEAT')
            _start_index = _begin_index + 15
            _end_index = _sentence.find(']')

            if _sentence.find('#DEFINE_REPEAT') is not None:
                _sub_list = _sentence[_start_index:_end_index].split(',')
                _choice = _sub_list[0]
                _repeat_text = _sub_list[1]
                _repeat_dict[_choice] = _repeat_text
                _sentence = _sentence.replace(_sentence[_begin_index:_end_index + 1], '', 1)

        while _sentence.find('#REPEAT') != -1:
            if _sentence.find('#REPEAT') is not None:
                _repeat_begin_index = _sentence.find('#REPEAT')
                _repeat_start_index = _repeat_begin_index + 8
                # by searching from _repeat_index below we don't encounter dodgy bracket-matching errors.
                _repeat_end_index = _sentence.find(']', _repeat_start_index)
                _repeat_index = _sentence[_repeat_start_index:_repeat_end_index]

                if _repeat_index in _repeat_dict:
                    _sentence = _sentence.replace(_sentence[_repeat_begin_index:_repeat_end_index + 1],
                                                  str(_repeat_dict[_repeat_index]))

        if _sentence.find('#REPEAT') == -1:
            return _sentence
        return _sentence
    else:
        return _sentence


def __replace_capitalise(_sentence):
    """here we replace all instances of #CAPITALISE and cap the next word.
    ############

    #NOTE:  Buggy as hell, as it doesn't account for words that are already
    #capitalized
    ############

    :param _sentence:
    """

    if _sentence is not None:
        while _sentence.find('#CAPITALISE') != -1:

            _cap_index = _sentence.find('#CAPITALISE')
            _part1 = _sentence[:_cap_index]
            _part2 = _sentence[_cap_index + 12:_cap_index + 13]
            _part3 = _sentence[_cap_index + 13:]

            if _part2 in "abcdefghijklmnopqrstuvwxyz":
                _sentence = _part1 + _part2.capitalize() + _part3
            else:
                _sentence = _part1 + _part2 + _part3

        if _sentence.find('#CAPITALISE') == -1:
            return _sentence
    else:
        return _sentence


def __replace_capall(_sentence):
    """here we replace all instances of #CAPALL and cap the entire sentence.
    Don't believe that CAPALL is buggy anymore as it forces all uppercase OK?

    :param _sentence:
        """

    # print "\nReplacing CAPITALISE:  "

    if _sentence is not None:
        while _sentence.find('#CAPALL') != -1:
            # _cap_index = _sentence.find('#CAPALL')
            _sentence = _sentence.upper()
            _sentence = _sentence.replace('#CAPALL ', '', 1)

        if _sentence.find('#CAPALL') == -1:
            return _sentence
    else:
        return _sentence


def __check_spaces(_sentence):
    """
    Here we check to see that we have the correct number of spaces in the correct locations.

    :param _sentence:
    :return:
    """
    # We have to run the process multiple times:
    #   Once to search for all spaces, and check if there are adjoining spaces;
    #   The second time to check for 2 spaces after sentence-ending characters such as . and ! and ?

    if _sentence is not None:

        words = _sentence.split()

        new_sentence = ''

        for (i, word) in enumerate(words):

            if word[-1] in set('.!?'):
                word += ' '
            new_word = ''.join(word)
            new_sentence += ' ' + new_word

        # remove any trailing whitespace
        new_sentence = new_sentence.lstrip()
        new_sentence = new_sentence.rstrip()

        return new_sentence
